import zeep

# Skautská telefonní síť (nová)
class TelephonyNetwork:
    __module__ = 'skautis'

    def __init__(self, test):
        if test:
            self._client = zeep.Client('https://test-is.skaut.cz/JunakWebservice/TelephonyNetwork.asmx?wsdl')
        else:
            self._client = zeep.Client('https://is.skaut.cz/JunakWebservice/TelephonyNetwork.asmx?wsdl')

    # Načíst informace o telefonních číslech v STS
    def PersonNumberInfoAll(self, ID_Login, ID, ID_Person, ID_Unit):
        return self._client.service.PersonNumberInfoAll({"ID_Login": ID_Login, "ID": ID, "ID_Person": ID_Person, "ID_Unit": ID_Unit})

    # Načíst seznam přihlášek do STS
    def EnrollAll(self, ID_Login, ID, ID_Person):
        return self._client.service.EnrollAll({"ID_Login": ID_Login, "ID": ID, "ID_Person": ID_Person})

    # Smazat přihlášku do STS
    def EnrollDelete(self, ID_Login, ID):
        return self._client.service.EnrollDelete({"ID_Login": ID_Login, "ID": ID})

    # Načíst přihlášku uživatele
    def EnrollDetailLogin(self, ID_Login, ID_Person):
        return self._client.service.EnrollDetailLogin({"ID_Login": ID_Login, "ID_Person": ID_Person})

    # Načíst detail přihlášky do STS
    def EnrollDetail(self, ID_Login, ID, ID_Person):
        return self._client.service.EnrollDetail({"ID_Login": ID_Login, "ID": ID, "ID_Person": ID_Person})

    # Ukončit přihlášku do STS
    def EnrollUpdateCancel(self, ID_Login, ID, ID_Person):
        return self._client.service.EnrollUpdateCancel({"ID_Login": ID_Login, "ID": ID, "ID_Person": ID_Person})

    # Založit přihlášku do STS pro osobu
    def EnrollInsertPerson(self, ID_Login, ID, ID_Person, ValidFrom, ValidTo, IsValid, Agreement):
        return self._client.service.EnrollInsertPerson({"ID_Login": ID_Login, "ID": ID, "ID_Person": ID_Person, "ValidFrom": ValidFrom, "ValidTo": ValidTo, "IsValid": IsValid, "Agreement": Agreement})

    # Načíst seznam přístupových kódu do STS
    def EntryCodeAll(self, ID_Login, ID):
        return self._client.service.EntryCodeAll({"ID_Login": ID_Login, "ID": ID})

    # Načíst detail platného přístupového kódu do STS
    def EntryCodeDetailValid(self, ID_Login, ID_Person):
        return self._client.service.EntryCodeDetailValid({"ID_Login": ID_Login, "ID_Person": ID_Person})




import zeep

# Uvítací balíčky
class Welcome:
    __module__ = 'skautis'

    def __init__(self, test):
        if test:
            self._client = zeep.Client('https://test-is.skaut.cz/JunakWebservice/Welcome.asmx?wsdl')
        else:
            self._client = zeep.Client('https://is.skaut.cz/JunakWebservice/Welcome.asmx?wsdl')

    # Načíst seznam vazeb funkcí a uvítacího balíčku
    def WelcomeFunctionAll(self, ID_Login, ID_Welcome, ID, ID_FunctionType):
        return self._client.service.WelcomeFunctionAll({"ID_Login": ID_Login, "ID_Welcome": ID_Welcome, "ID": ID, "ID_FunctionType": ID_FunctionType})

    # Smazat vazbu funkce a uvítacího balíčku
    def WelcomeFunctionDelete(self, ID_Login, ID):
        return self._client.service.WelcomeFunctionDelete({"ID_Login": ID_Login, "ID": ID})

    # Založit vazbu funkce a uvítacího balíčku
    def WelcomeFunctionInsert(self, ID_Login, ID, ID_Welcome, ID_FunctionType, Welcome=None, FunctionType=None):
        return self._client.service.WelcomeFunctionInsert({"ID_Login": ID_Login, "ID": ID, "ID_Welcome": ID_Welcome, "ID_FunctionType": ID_FunctionType, "Welcome": Welcome, "FunctionType": FunctionType})

    # Odeslat balíček k otestování
    def WelcomeMessage(self, ID_Login, ID, ID_Person, ID_FunctionType):
        return self._client.service.WelcomeMessage({"ID_Login": ID_Login, "ID": ID, "ID_Person": ID_Person, "ID_FunctionType": ID_FunctionType})

    # Odeslat balíček
    def WelcomeSentInsert(self, ID_Login, ID_Function, ID_Welcome):
        return self._client.service.WelcomeSentInsert({"ID_Login": ID_Login, "ID_Function": ID_Function, "ID_Welcome": ID_Welcome})

    # Odeslání balíčků
    def WelcomeSentUpdateSend(self, ID_Login):
        return self._client.service.WelcomeSentUpdateSend({"ID_Login": ID_Login})

    # Odeslat balíček všem v dané funkci
    def WelcomeUpdateSend(self, ID_Login, ID):
        return self._client.service.WelcomeUpdateSend({"ID_Login": ID_Login, "ID": ID})

    # Upravit uvítací balíček
    def WelcomeUpdate(self, ID_Login, ID, IsEnabled, IsParentUnit, IsSupervisorSent, SendToAll, IsFinal, DisplayName=None, Functions=None):
        return self._client.service.WelcomeUpdate({"ID_Login": ID_Login, "ID": ID, "IsEnabled": IsEnabled, "IsParentUnit": IsParentUnit, "IsSupervisorSent": IsSupervisorSent, "SendToAll": SendToAll, "IsFinal": IsFinal, "DisplayName": DisplayName, "Functions": Functions})

    # Načíst seznam pruhů balíčku
    def StripeAll(self, ID_Login, ID_Welcome, ID_AlignmentType, DisplayName=None, ID_Sex=None):
        return self._client.service.StripeAll({"ID_Login": ID_Login, "ID_Welcome": ID_Welcome, "ID_AlignmentType": ID_AlignmentType, "DisplayName": DisplayName, "ID_Sex": ID_Sex})

    # Načíst seznam příloh pruhu
    def StripeAttachmentAll(self, ID_Login, ID_Stripe, IsHtmlImage, DisplayName=None):
        return self._client.service.StripeAttachmentAll({"ID_Login": ID_Login, "ID_Stripe": ID_Stripe, "IsHtmlImage": IsHtmlImage, "DisplayName": DisplayName})

    # Smazat přílohu pruhu
    def StripeAttachmentDelete(self, ID_Login, ID):
        return self._client.service.StripeAttachmentDelete({"ID_Login": ID_Login, "ID": ID})

    # Stáhne přílohu pruhu
    def StripeAttachmentDownload(self, ID_Login, ID):
        return self._client.service.StripeAttachmentDownload({"ID_Login": ID_Login, "ID": ID})

    # Založit přílohu pruhu
    def StripeAttachmentInsert(self, ID_Login, ID, ID_Stripe, IsHtmlImage, DisplayName=None, Extension=None, Content=None):
        return self._client.service.StripeAttachmentInsert({"ID_Login": ID_Login, "ID": ID, "ID_Stripe": ID_Stripe, "IsHtmlImage": IsHtmlImage, "DisplayName": DisplayName, "Extension": Extension, "Content": Content})

    # Upravit přílohu pruhu
    def StripeAttachmentUpdate(self, ID_Login, ID, ID_Stripe, IsHtmlImage, DisplayName=None, Extension=None, Content=None):
        return self._client.service.StripeAttachmentUpdate({"ID_Login": ID_Login, "ID": ID, "ID_Stripe": ID_Stripe, "IsHtmlImage": IsHtmlImage, "DisplayName": DisplayName, "Extension": Extension, "Content": Content})

    # Smazat pruh balíčku
    def StripeDelete(self, ID_Login, ID):
        return self._client.service.StripeDelete({"ID_Login": ID_Login, "ID": ID})

    # Načíst detail pruhu balíčku
    def StripeDetail(self, ID_Login, ID):
        return self._client.service.StripeDetail({"ID_Login": ID_Login, "ID": ID})

    # Založit pruh balíčku
    def StripeInsert(self, ID_Login, ID, ID_Welcome, Order, IsNew, ID_AlignmentType, IsWarning, Welcome=None, DisplayName=None, Text=None, ID_Sex=None, Sex=None, AlignmentType=None):
        return self._client.service.StripeInsert({"ID_Login": ID_Login, "ID": ID, "ID_Welcome": ID_Welcome, "Order": Order, "IsNew": IsNew, "ID_AlignmentType": ID_AlignmentType, "IsWarning": IsWarning, "Welcome": Welcome, "DisplayName": DisplayName, "Text": Text, "ID_Sex": ID_Sex, "Sex": Sex, "AlignmentType": AlignmentType})

    # Upravit pruh balíčku
    def StripeUpdate(self, ID_Login, ID, ID_Welcome, Order, IsNew, ID_AlignmentType, IsWarning, Welcome=None, DisplayName=None, Text=None, ID_Sex=None, Sex=None, AlignmentType=None):
        return self._client.service.StripeUpdate({"ID_Login": ID_Login, "ID": ID, "ID_Welcome": ID_Welcome, "Order": Order, "IsNew": IsNew, "ID_AlignmentType": ID_AlignmentType, "IsWarning": IsWarning, "Welcome": Welcome, "DisplayName": DisplayName, "Text": Text, "ID_Sex": ID_Sex, "Sex": Sex, "AlignmentType": AlignmentType})

    # Načíst seznam uvítacích balíčků
    def WelcomeAll(self, ID_Login, ID_FunctionType, SendToAll, IsEnabled, DisplayName=None, ID_UnitType=None):
        return self._client.service.WelcomeAll({"ID_Login": ID_Login, "ID_FunctionType": ID_FunctionType, "SendToAll": SendToAll, "IsEnabled": IsEnabled, "DisplayName": DisplayName, "ID_UnitType": ID_UnitType})

    # Načíst detail uvítacího balíčku
    def WelcomeDetail(self, ID_Login, ID):
        return self._client.service.WelcomeDetail({"ID_Login": ID_Login, "ID": ID})

    # Založit uvítací balíček
    def WelcomeInsert(self, ID_Login, IsEnabled, IsParentUnit, IsFinal, Functions=None, DisplayName=None):
        return self._client.service.WelcomeInsert({"ID_Login": ID_Login, "IsEnabled": IsEnabled, "IsParentUnit": IsParentUnit, "IsFinal": IsFinal, "Functions": Functions, "DisplayName": DisplayName})

    # Načíst seznam odeslání balíčků
    def WelcomeSentAll(self, ID_Login, ID_Unit, ID_Welcome):
        return self._client.service.WelcomeSentAll({"ID_Login": ID_Login, "ID_Unit": ID_Unit, "ID_Welcome": ID_Welcome})

    # Upravit odeslání balíčku
    def WelcomeSentUpdate(self, ID_Login, ID):
        return self._client.service.WelcomeSentUpdate({"ID_Login": ID_Login, "ID": ID})

    # Připravit balíček k odeslání všem v dané funkci
    def WelcomeUpdatePrepareSend(self, ID_Login, ID):
        return self._client.service.WelcomeUpdatePrepareSend({"ID_Login": ID_Login, "ID": ID})

    # Načíst seznam proměnných balíčku
    def WelcomeVariableAll(self, ID_Login, DisplayName=None):
        return self._client.service.WelcomeVariableAll({"ID_Login": ID_Login, "DisplayName": DisplayName})




import zeep

# Webová služba pro práci s dokumentovým úložištěm
class DocumentStorage:
    __module__ = 'skautis'

    def __init__(self, test):
        if test:
            self._client = zeep.Client('https://test-is.skaut.cz/JunakWebservice/DocumentStorage.asmx?wsdl')
        else:
            self._client = zeep.Client('https://is.skaut.cz/JunakWebservice/DocumentStorage.asmx?wsdl')

    # Načíst seznam cloudových záznamů
    def CloudAll(self, ID_Login, ID, ID_DocumentVersion, ID_CloudState=None):
        return self._client.service.CloudAll({"ID_Login": ID_Login, "ID": ID, "ID_DocumentVersion": ID_DocumentVersion, "ID_CloudState": ID_CloudState})

    # Smazat cloudový záznam
    def CloudDelete(self, ID_Login, ID):
        return self._client.service.CloudDelete({"ID_Login": ID_Login, "ID": ID})

    # Načíst detail cloudového záznamu
    def CloudDetail(self, ID_Login, ID):
        return self._client.service.CloudDetail({"ID_Login": ID_Login, "ID": ID})

    # Načíst seznam cache cloudového záznamu
    def CloudFolderCacheAll(self, ID_Login, ID_DocumentVersion=None):
        return self._client.service.CloudFolderCacheAll({"ID_Login": ID_Login, "ID_DocumentVersion": ID_DocumentVersion})

    # Založit cache cloudového záznamu
    def CloudFolderCacheInsert(self, ID_Login, ID, Date, Path=None, CloudGuid=None):
        return self._client.service.CloudFolderCacheInsert({"ID_Login": ID_Login, "ID": ID, "Date": Date, "Path": Path, "CloudGuid": CloudGuid})

    # Založit cloudový záznam
    def CloudInsert(self, ID_Login, ID_Application, ID, ID_DocumentVersion, ValidTo, DocumentVersion=None, ID_CloudState=None, CloudState=None, CloudGuid=None):
        return self._client.service.CloudInsert({"ID_Login": ID_Login, "ID_Application": ID_Application, "ID": ID, "ID_DocumentVersion": ID_DocumentVersion, "ValidTo": ValidTo, "DocumentVersion": DocumentVersion, "ID_CloudState": ID_CloudState, "CloudState": CloudState, "CloudGuid": CloudGuid})

    # Načíst seznam požadavků na dokument
    def CloudRequestAll(self, ID_Login, ID_Cloud, ID, ID_User):
        return self._client.service.CloudRequestAll({"ID_Login": ID_Login, "ID_Cloud": ID_Cloud, "ID": ID, "ID_User": ID_User})

    # Smazat požadavek na dokument
    def CloudRequestDelete(self, ID_Login, ID):
        return self._client.service.CloudRequestDelete({"ID_Login": ID_Login, "ID": ID})

    # Načíst detail požadavku na dokument
    def CloudRequestDetail(self, ID_Login, ID):
        return self._client.service.CloudRequestDetail({"ID_Login": ID_Login, "ID": ID})

    # Založit požadavek na dokument
    def CloudRequestInsert(self, ID_Login, ID, ID_User, ID_Cloud):
        return self._client.service.CloudRequestInsert({"ID_Login": ID_Login, "ID": ID, "ID_User": ID_User, "ID_Cloud": ID_Cloud})

    # Upravit požadavek na dokument
    def CloudRequestUpdate(self, ID_Login, ID, ID_User, ID_Cloud):
        return self._client.service.CloudRequestUpdate({"ID_Login": ID_Login, "ID": ID, "ID_User": ID_User, "ID_Cloud": ID_Cloud})

    # Načíst seznam stavů záznamu (v Cloudu)
    def CloudStateAll(self, ID_Application, ID_Login, ID=None, DisplayName=None):
        return self._client.service.CloudStateAll({"ID_Application": ID_Application, "ID_Login": ID_Login, "ID": ID, "DisplayName": DisplayName})

    # Načíst detail stavu záznamu (v Cloudu)
    def CloudStateDetail(self, ID_Login, ID=None):
        return self._client.service.CloudStateDetail({"ID_Login": ID_Login, "ID": ID})

    # Upravit cloudový záznam
    def CloudUpdateDocumentVersion(self, ID_Login, ID_Application, ID, ID_DocumentVersion, ValidTo, DocumentVersion=None, ID_CloudState=None, CloudState=None, CloudGuid=None):
        return self._client.service.CloudUpdateDocumentVersion({"ID_Login": ID_Login, "ID_Application": ID_Application, "ID": ID, "ID_DocumentVersion": ID_DocumentVersion, "ValidTo": ValidTo, "DocumentVersion": DocumentVersion, "ID_CloudState": ID_CloudState, "CloudState": CloudState, "CloudGuid": CloudGuid})

    # Upravit cloudový záznam
    def CloudUpdate(self, ID_Login, ID_Application, ID, ID_DocumentVersion, ValidTo, DocumentVersion=None, ID_CloudState=None, CloudState=None, CloudGuid=None):
        return self._client.service.CloudUpdate({"ID_Login": ID_Login, "ID_Application": ID_Application, "ID": ID, "ID_DocumentVersion": ID_DocumentVersion, "ValidTo": ValidTo, "DocumentVersion": DocumentVersion, "ID_CloudState": ID_CloudState, "CloudState": CloudState, "CloudGuid": CloudGuid})

    # Načíst seznam dokumentů
    def DocumentAllUnused(self, ID_Login):
        return self._client.service.DocumentAllUnused({"ID_Login": ID_Login})

    # Načíst seznam dokumentů
    def DocumentAll(self, ID_Application, ID_Login, ID, ID_DocumentVersion, ID_DocumentClass=None):
        return self._client.service.DocumentAll({"ID_Application": ID_Application, "ID_Login": ID_Login, "ID": ID, "ID_DocumentVersion": ID_DocumentVersion, "ID_DocumentClass": ID_DocumentClass})

    # Načíst seznam tříd dokumentu
    def DocumentClassAll(self, ID_Application, ID_Login, ID=None, DisplayName=None, ID_Table=None, ID_ActionDetail=None, ID_ActionEdit=None, ID_ActionDel=None):
        return self._client.service.DocumentClassAll({"ID_Application": ID_Application, "ID_Login": ID_Login, "ID": ID, "DisplayName": DisplayName, "ID_Table": ID_Table, "ID_ActionDetail": ID_ActionDetail, "ID_ActionEdit": ID_ActionEdit, "ID_ActionDel": ID_ActionDel})

    # Načíst detail třídy dokumentu
    def DocumentClassDetail(self, ID_Login, ID=None):
        return self._client.service.DocumentClassDetail({"ID_Login": ID_Login, "ID": ID})

    # Smazat dokument
    def DocumentDelete(self, ID_Login, ID, CheckPermissions):
        return self._client.service.DocumentDelete({"ID_Login": ID_Login, "ID": ID, "CheckPermissions": CheckPermissions})

    # Načíst data dokumentu
    def DocumentDetailData(self, ID_Application, ID_Login, ID):
        return self._client.service.DocumentDetailData({"ID_Application": ID_Application, "ID_Login": ID_Login, "ID": ID})

    # Načíst detail dokumentu
    def DocumentDetail(self, ID_Application, ID_Login, ID):
        return self._client.service.DocumentDetail({"ID_Application": ID_Application, "ID_Login": ID_Login, "ID": ID})

    # Založit dokument
    def DocumentInsert(self, ID_Login, ID, ID_DocumentVersion, Created, Date, ID_Document, ID_User, ID_Person, Size, Version, ImageWidth, ImageHeight, UseCurrentVersion, ID_Cloud, CloudValidTo, DocumentVersion=None, ID_DocumentClass=None, DocumentClass=None, DisplayName=None, Person=None, FileName=None, ContentType=None, Extension=None, Hash=None, Storage=None, FileNameExtension=None, ID_CloudState=None, CloudGuid=None):
        return self._client.service.DocumentInsert({"ID_Login": ID_Login, "ID": ID, "ID_DocumentVersion": ID_DocumentVersion, "Created": Created, "Date": Date, "ID_Document": ID_Document, "ID_User": ID_User, "ID_Person": ID_Person, "Size": Size, "Version": Version, "ImageWidth": ImageWidth, "ImageHeight": ImageHeight, "UseCurrentVersion": UseCurrentVersion, "ID_Cloud": ID_Cloud, "CloudValidTo": CloudValidTo, "DocumentVersion": DocumentVersion, "ID_DocumentClass": ID_DocumentClass, "DocumentClass": DocumentClass, "DisplayName": DisplayName, "Person": Person, "FileName": FileName, "ContentType": ContentType, "Extension": Extension, "Hash": Hash, "Storage": Storage, "FileNameExtension": FileNameExtension, "ID_CloudState": ID_CloudState, "CloudGuid": CloudGuid})

    # Smazat dokument v tabulce
    def DocumentDeleteDocumentInTable(self, ID_Login, ID, ID_DocumentClass=None, Table=None, TableAction=None, Column=None):
        return self._client.service.DocumentDeleteDocumentInTable({"ID_Login": ID_Login, "ID": ID, "ID_DocumentClass": ID_DocumentClass, "Table": Table, "TableAction": TableAction, "Column": Column})

    # Upravit dokument v tabulce
    def DocumentUpdateDocumentInTable(self, ID_Login, ID, ID_TempFile, MoveDocument, ID_RelatedTable, ID_DocumentClass=None, Table=None, TableAction=None, Column=None):
        return self._client.service.DocumentUpdateDocumentInTable({"ID_Login": ID_Login, "ID": ID, "ID_TempFile": ID_TempFile, "MoveDocument": MoveDocument, "ID_RelatedTable": ID_RelatedTable, "ID_DocumentClass": ID_DocumentClass, "Table": Table, "TableAction": TableAction, "Column": Column})

    # Upravit dokument
    def DocumentUpdate(self, ID_Login, ID, ID_DocumentVersion, Created, Date, ID_Document, ID_User, ID_Person, Size, Version, ImageWidth, ImageHeight, UseCurrentVersion, ID_Cloud, CloudValidTo, DocumentVersion=None, ID_DocumentClass=None, DocumentClass=None, DisplayName=None, Person=None, FileName=None, ContentType=None, Extension=None, Hash=None, Storage=None, FileNameExtension=None, ID_CloudState=None, CloudGuid=None):
        return self._client.service.DocumentUpdate({"ID_Login": ID_Login, "ID": ID, "ID_DocumentVersion": ID_DocumentVersion, "Created": Created, "Date": Date, "ID_Document": ID_Document, "ID_User": ID_User, "ID_Person": ID_Person, "Size": Size, "Version": Version, "ImageWidth": ImageWidth, "ImageHeight": ImageHeight, "UseCurrentVersion": UseCurrentVersion, "ID_Cloud": ID_Cloud, "CloudValidTo": CloudValidTo, "DocumentVersion": DocumentVersion, "ID_DocumentClass": ID_DocumentClass, "DocumentClass": DocumentClass, "DisplayName": DisplayName, "Person": Person, "FileName": FileName, "ContentType": ContentType, "Extension": Extension, "Hash": Hash, "Storage": Storage, "FileNameExtension": FileNameExtension, "ID_CloudState": ID_CloudState, "CloudGuid": CloudGuid})

    # Načíst seznam verzí dokumentu
    def DocumentVersionAllToBackup(self, ID_Login):
        return self._client.service.DocumentVersionAllToBackup({"ID_Login": ID_Login})

    # Načíst seznam verzí dokumentu
    def DocumentVersionAll(self, ID_Login, ID, ID_Document, ID_User, DisplayName=None):
        return self._client.service.DocumentVersionAll({"ID_Login": ID_Login, "ID": ID, "ID_Document": ID_Document, "ID_User": ID_User, "DisplayName": DisplayName})

    # Smazat verzi dokumentu
    def DocumentVersionDelete(self, ID_Login, ID):
        return self._client.service.DocumentVersionDelete({"ID_Login": ID_Login, "ID": ID})

    # Načíst detail verze dokumentu
    def DocumentVersionDetail(self, ID_Login, ID):
        return self._client.service.DocumentVersionDetail({"ID_Login": ID_Login, "ID": ID})

    # Založit verzi dokumentu
    def DocumentVersionInsert(self, ID_Login, ID, Date, ID_Document, ID_User, Size, Version, ImageWidth, ImageHeight, DisplayName=None, FileName=None, ContentType=None, Extension=None, Hash=None, Storage=None, FileNameExtension=None):
        return self._client.service.DocumentVersionInsert({"ID_Login": ID_Login, "ID": ID, "Date": Date, "ID_Document": ID_Document, "ID_User": ID_User, "Size": Size, "Version": Version, "ImageWidth": ImageWidth, "ImageHeight": ImageHeight, "DisplayName": DisplayName, "FileName": FileName, "ContentType": ContentType, "Extension": Extension, "Hash": Hash, "Storage": Storage, "FileNameExtension": FileNameExtension})

    # Upravit verzi dokumentu
    def DocumentVersionUpdate(self, ID_Login, ID, Date, ID_Document, ID_User, Size, Version, ImageWidth, ImageHeight, DisplayName=None, FileName=None, ContentType=None, Extension=None, Hash=None, Storage=None, FileNameExtension=None):
        return self._client.service.DocumentVersionUpdate({"ID_Login": ID_Login, "ID": ID, "Date": Date, "ID_Document": ID_Document, "ID_User": ID_User, "Size": Size, "Version": Version, "ImageWidth": ImageWidth, "ImageHeight": ImageHeight, "DisplayName": DisplayName, "FileName": FileName, "ContentType": ContentType, "Extension": Extension, "Hash": Hash, "Storage": Storage, "FileNameExtension": FileNameExtension})




import zeep

# Interní zpravodajský systém
class Message:
    __module__ = 'skautis'

    def __init__(self, test):
        if test:
            self._client = zeep.Client('https://test-is.skaut.cz/JunakWebservice/Message.asmx?wsdl')
        else:
            self._client = zeep.Client('https://is.skaut.cz/JunakWebservice/Message.asmx?wsdl')

    # Načíst seznam typů příloh zpráv pro editaci šablony zprávy
    def MessageAttachmentTypeAllMultiple(self, ID_Login, ID_MessageType=None):
        return self._client.service.MessageAttachmentTypeAllMultiple({"ID_Login": ID_Login, "ID_MessageType": ID_MessageType})

    # Načíst seznam typů příloh zpráv
    def MessageAttachmentTypeAll(self, ID_Login, ID_MessageType=None):
        return self._client.service.MessageAttachmentTypeAll({"ID_Login": ID_Login, "ID_MessageType": ID_MessageType})

    # Načíst seznam skupin zpráv
    def MessageGroupAll(self, ID_Login, DisplayName=None, ReplyTo=None):
        return self._client.service.MessageGroupAll({"ID_Login": ID_Login, "DisplayName": DisplayName, "ReplyTo": ReplyTo})

    # Smazat skupinu zpráv
    def MessageGroupDelete(self, ID_Login, ID):
        return self._client.service.MessageGroupDelete({"ID_Login": ID_Login, "ID": ID})

    # Načíst detail skupiny zpráv
    def MessageGroupDetail(self, ID_Login, ID):
        return self._client.service.MessageGroupDetail({"ID_Login": ID_Login, "ID": ID})

    # Založit skupinu zpráv
    def MessageGroupInsert(self, ID_Login, ID, DisplayName=None, ReplyTo=None, Footer=None, FooterHtml=None, Note=None):
        return self._client.service.MessageGroupInsert({"ID_Login": ID_Login, "ID": ID, "DisplayName": DisplayName, "ReplyTo": ReplyTo, "Footer": Footer, "FooterHtml": FooterHtml, "Note": Note})

    # Načíst seznam zasílaných skupin zpráv osobě
    def MessageGroupPersonAll(self, ID_Login, ID_Person, ID_MessageGroup):
        return self._client.service.MessageGroupPersonAll({"ID_Login": ID_Login, "ID_Person": ID_Person, "ID_MessageGroup": ID_MessageGroup})

    # Upravit skupinu zpráv
    def MessageGroupUpdate(self, ID_Login, ID, DisplayName=None, ReplyTo=None, Footer=None, FooterHtml=None, Note=None):
        return self._client.service.MessageGroupUpdate({"ID_Login": ID_Login, "ID": ID, "DisplayName": DisplayName, "ReplyTo": ReplyTo, "Footer": Footer, "FooterHtml": FooterHtml, "Note": Note})

    # Načíst detail typu zprávy
    def MessageTypeDetail(self, ID_Login, ID=None):
        return self._client.service.MessageTypeDetail({"ID_Login": ID_Login, "ID": ID})

    # Upravit typ zprávy
    def MessageTypeUpdate(self, ID_Login, ID_MessageGroup, AllwaysEmail, ID=None, DisplayName=None, MessageGroup=None, Procedure=None, Note=None):
        return self._client.service.MessageTypeUpdate({"ID_Login": ID_Login, "ID_MessageGroup": ID_MessageGroup, "AllwaysEmail": AllwaysEmail, "ID": ID, "DisplayName": DisplayName, "MessageGroup": MessageGroup, "Procedure": Procedure, "Note": Note})

    # Smazat či obnovit zprávu
    def MessageUpdateDelete(self, ID_Login, ID, Delete):
        return self._client.service.MessageUpdateDelete({"ID_Login": ID_Login, "ID": ID, "Delete": Delete})

    # Ozančit zprávu jako přečtenou či nepřečtenou
    def MessageUpdateRead(self, ID_Login, ID, IsRead):
        return self._client.service.MessageUpdateRead({"ID_Login": ID_Login, "ID": ID, "IsRead": IsRead})

    # Nastavit příjemci, že byl odeslaný
    def MessageToSent(self, ID_Login, ID, Error=None):
        return self._client.service.MessageToSent({"ID_Login": ID_Login, "ID": ID, "Error": Error})

    # Načíst seznam webových zpráv přihlášeného uživatele
    def MessageAllWeb(self, ID_Login, ID_MessageGroup, IsRead, HasAttachments, IsActive, DateCreateFrom, DateCreateTo, Top, ID_MessageType=None, DisplayName=None):
        return self._client.service.MessageAllWeb({"ID_Login": ID_Login, "ID_MessageGroup": ID_MessageGroup, "IsRead": IsRead, "HasAttachments": HasAttachments, "IsActive": IsActive, "DateCreateFrom": DateCreateFrom, "DateCreateTo": DateCreateTo, "Top": Top, "ID_MessageType": ID_MessageType, "DisplayName": DisplayName})

    # Načíst seznam e-mailů k odeslání
    def MessageAll(self, ID_Login, InstanceKey=None):
        return self._client.service.MessageAll({"ID_Login": ID_Login, "InstanceKey": InstanceKey})

    # Načíst seznam příloh zprávy
    def MessageAttachmentAll(self, ID_Login, ID, ID_Message, IsHtmlImage):
        return self._client.service.MessageAttachmentAll({"ID_Login": ID_Login, "ID": ID, "ID_Message": ID_Message, "IsHtmlImage": IsHtmlImage})

    # Načíst detail zprávy (zpráva se zavoláním této funkce automaticky nastaví jako přečtená)
    def MessageDetail(self, ID_Login, ID):
        return self._client.service.MessageDetail({"ID_Login": ID_Login, "ID": ID})

    # Načíst nastavení zpráv přihlášené osoby
    def MessageMediumPersonAll(self, ID_Login, ID_Person, ID_MessageMedium=None):
        return self._client.service.MessageMediumPersonAll({"ID_Login": ID_Login, "ID_Person": ID_Person, "ID_MessageMedium": ID_MessageMedium})

    # Upravit nastavení zpráv
    def MessageMediumPersonUpdate(self, ID_Login, ID_Person, Subscribe, AllGroups, ID_MessageMedium=None, ID_MessageGroupArray=None):
        return self._client.service.MessageMediumPersonUpdate({"ID_Login": ID_Login, "ID_Person": ID_Person, "Subscribe": Subscribe, "AllGroups": AllGroups, "ID_MessageMedium": ID_MessageMedium, "ID_MessageGroupArray": ID_MessageGroupArray})

    # Načíst seznam šablon zpráv
    def MessageTemplateAll(self, ID_Login, ID_MessageType=None, ID_MessageMedium=None, DisplayName=None):
        return self._client.service.MessageTemplateAll({"ID_Login": ID_Login, "ID_MessageType": ID_MessageType, "ID_MessageMedium": ID_MessageMedium, "DisplayName": DisplayName})

    # Načíst detail šablony zprávy
    def MessageTemplateDetail(self, ID_Login, ID):
        return self._client.service.MessageTemplateDetail({"ID_Login": ID_Login, "ID": ID})

    # Upravit šablonu zprávy
    def MessageTemplateUpdate(self, ID_Login, ID, IsAttachmentVisible, ID_MessageType=None, MessageType=None, ID_MessageMedium=None, MessageMedium=None, DisplayName=None, Body=None):
        return self._client.service.MessageTemplateUpdate({"ID_Login": ID_Login, "ID": ID, "IsAttachmentVisible": IsAttachmentVisible, "ID_MessageType": ID_MessageType, "MessageType": MessageType, "ID_MessageMedium": ID_MessageMedium, "MessageMedium": MessageMedium, "DisplayName": DisplayName, "Body": Body})

    # Načíst seznam příjemců zprávy
    def MessageToAll(self, ID_Login, ID_Message):
        return self._client.service.MessageToAll({"ID_Login": ID_Login, "ID_Message": ID_Message})

    # Načíst seznam typů zpráv
    def MessageTypeAll(self, ID_Login, ID_MessageGroup, DisplayName=None, Key=None):
        return self._client.service.MessageTypeAll({"ID_Login": ID_Login, "ID_MessageGroup": ID_MessageGroup, "DisplayName": DisplayName, "Key": Key})

    # Upravit zprávu
    def MessageUpdate(self, ID_Login, ID, ID_MessageState=None):
        return self._client.service.MessageUpdate({"ID_Login": ID_Login, "ID": ID, "ID_MessageState": ID_MessageState})

    # Načíst seznam proměnných v šablonách zpráv
    def MessageVariableAll(self, ID_Login, DisplayName=None, ID_MessageType=None):
        return self._client.service.MessageVariableAll({"ID_Login": ID_Login, "DisplayName": DisplayName, "ID_MessageType": ID_MessageType})




import zeep

# Webová služba pro práci s GoogleApps (zápis dat do databáze, komunikace s GoogleApps)
class GoogleApps:
    __module__ = 'skautis'

    def __init__(self, test):
        if test:
            self._client = zeep.Client('https://test-is.skaut.cz/JunakWebservice/GoogleApps.asmx?wsdl')
        else:
            self._client = zeep.Client('https://is.skaut.cz/JunakWebservice/GoogleApps.asmx?wsdl')

    # Načíst seznam využití sdílených disků jednotky
    def SharedDriveAllUnitUsage(self, ID_Login, ID_Unit):
        return self._client.service.SharedDriveAllUnitUsage({"ID_Login": ID_Login, "ID_Unit": ID_Unit})

    # Načíst seznam sdílených disků jednotky
    def SharedDriveAllUnit(self, ID_Login, ID_Unit):
        return self._client.service.SharedDriveAllUnit({"ID_Login": ID_Login, "ID_Unit": ID_Unit})

    # Načíst seznam názvů akcí pro sdílené disky jednotky
    def SharedDriveAllEvents(self, ID_Login, ID_Unit, AddSystemItem, DisplayName=None):
        return self._client.service.SharedDriveAllEvents({"ID_Login": ID_Login, "ID_Unit": ID_Unit, "AddSystemItem": AddSystemItem, "DisplayName": DisplayName})

    # Aktualizovat využití sdíleného disku
    def SharedDriveUpdateUsage(self, ID_Login, ID, ID_Unit, DateCreated, ID_UserCreated, SpaceUsed, ID_PersonAdmin, DateUpdated, CheckConditions, ID_PersonCreated, ShowEventName, ShowAdminLink, DriveId=None, Unit=None, ID_SharedDriveType=None, SharedDriveType=None, DisplayName=None, EventName=None, UserCreated=None, AdminEmail=None, Note=None, OrgUnitPath=None, DateUpdatedClass=None):
        return self._client.service.SharedDriveUpdateUsage({"ID_Login": ID_Login, "ID": ID, "ID_Unit": ID_Unit, "DateCreated": DateCreated, "ID_UserCreated": ID_UserCreated, "SpaceUsed": SpaceUsed, "ID_PersonAdmin": ID_PersonAdmin, "DateUpdated": DateUpdated, "CheckConditions": CheckConditions, "ID_PersonCreated": ID_PersonCreated, "ShowEventName": ShowEventName, "ShowAdminLink": ShowAdminLink, "DriveId": DriveId, "Unit": Unit, "ID_SharedDriveType": ID_SharedDriveType, "SharedDriveType": SharedDriveType, "DisplayName": DisplayName, "EventName": EventName, "UserCreated": UserCreated, "AdminEmail": AdminEmail, "Note": Note, "OrgUnitPath": OrgUnitPath, "DateUpdatedClass": DateUpdatedClass})

    # Založit fixně nastavenou emailovou adresu v Google skupině dle emailu
    def SyncSettingsEmailInsertEmail(self, ID_Login, ID_GoogleGroup, EmailArray=None):
        return self._client.service.SyncSettingsEmailInsertEmail({"ID_Login": ID_Login, "ID_GoogleGroup": ID_GoogleGroup, "EmailArray": EmailArray})

    # Založit fixně nastavenou emailovou adresu v Google skupině dle osoby
    def SyncSettingsEmailInsertPerson(self, ID_Login, ID_GoogleGroup, ID_Person):
        return self._client.service.SyncSettingsEmailInsertPerson({"ID_Login": ID_Login, "ID_GoogleGroup": ID_GoogleGroup, "ID_Person": ID_Person})

    # Smazat fixně nastavenou emailovou adresu v Google skupině
    def SyncSettingsEmailDelete(self, ID_Login, ID, ID_GoogleGroup):
        return self._client.service.SyncSettingsEmailDelete({"ID_Login": ID_Login, "ID": ID, "ID_GoogleGroup": ID_GoogleGroup})

    # Načíst seznam fixně nastavených emailových adres v Google skupině
    def SyncSettingsEmailAll(self, ID_Login, ID_GoogleGroup):
        return self._client.service.SyncSettingsEmailAll({"ID_Login": ID_Login, "ID_GoogleGroup": ID_GoogleGroup})

    # Načíst seznam GA účtů k synchronizaci
    def GoogleAccountAllSync(self, ID_Login):
        return self._client.service.GoogleAccountAllSync({"ID_Login": ID_Login})

    # Načíst detail užití úložiště daného účtu v GA
    def GoogleAccountDetailStorage(self, ID_Login, ID):
        return self._client.service.GoogleAccountDetailStorage({"ID_Login": ID_Login, "ID": ID})

    # Načíst detail hlavního účtu jednotky v GA
    def GoogleAccountDetailOrganizationUnit(self, ID_Login, ID):
        return self._client.service.GoogleAccountDetailOrganizationUnit({"ID_Login": ID_Login, "ID": ID})

    # Nastavit organizační jednotku pro google účet
    def GoogleAccountUpdateOrganizationUnit(self, ID_Login, ID, OrganizationUnitId=None):
        return self._client.service.GoogleAccountUpdateOrganizationUnit({"ID_Login": ID_Login, "ID": ID, "OrganizationUnitId": OrganizationUnitId})

    # Načíst seznam organizačních jednotek v GA
    def GoogleUnitAll(self, ID_Login):
        return self._client.service.GoogleUnitAll({"ID_Login": ID_Login})

    # Načíst seznam google skupin pro synchronizaci
    def GoogleGroupAllSync(self, ID_Login):
        return self._client.service.GoogleGroupAllSync({"ID_Login": ID_Login})

    # Načíst seznam požadavků na synchronizaci
    def GoogleGroupSyncRequestAll(self, ID_Login, ID_GoogleGroup, ID):
        return self._client.service.GoogleGroupSyncRequestAll({"ID_Login": ID_Login, "ID_GoogleGroup": ID_GoogleGroup, "ID": ID})

    # Načíst seznam nastavení synchronizace Google skupiny
    def GoogleGroupSyncSettingsAll(self, ID_Login, ID_GoogleGroup, ID, ID_SyncLevelType=None, ID_SyncType=None):
        return self._client.service.GoogleGroupSyncSettingsAll({"ID_Login": ID_Login, "ID_GoogleGroup": ID_GoogleGroup, "ID": ID, "ID_SyncLevelType": ID_SyncLevelType, "ID_SyncType": ID_SyncType})

    # Smazat nastavení synchronizace Google skupiny
    def GoogleGroupSyncSettingsDelete(self, ID_Login, ID, ID_GoogleGroup, IsFunction, ID_Unit, GoogleGroup=None, ID_SyncLevelType=None, SyncLevelType=None, Units=None, SyncContactTypes=None, MembershipCategories=None, FunctionsDirect=None, Functions=None, ID_UnitType=None, DisplayName=None):
        return self._client.service.GoogleGroupSyncSettingsDelete({"ID_Login": ID_Login, "ID": ID, "ID_GoogleGroup": ID_GoogleGroup, "IsFunction": IsFunction, "ID_Unit": ID_Unit, "GoogleGroup": GoogleGroup, "ID_SyncLevelType": ID_SyncLevelType, "SyncLevelType": SyncLevelType, "Units": Units, "SyncContactTypes": SyncContactTypes, "MembershipCategories": MembershipCategories, "FunctionsDirect": FunctionsDirect, "Functions": Functions, "ID_UnitType": ID_UnitType, "DisplayName": DisplayName})

    # Založit nastavení synchronizace Google skupiny
    def GoogleGroupSyncSettingsInsert(self, ID_Login, ID, ID_GoogleGroup, IsFunction, ID_Unit, GoogleGroup=None, ID_SyncLevelType=None, SyncLevelType=None, Units=None, SyncContactTypes=None, MembershipCategories=None, FunctionsDirect=None, Functions=None, ID_UnitType=None, DisplayName=None):
        return self._client.service.GoogleGroupSyncSettingsInsert({"ID_Login": ID_Login, "ID": ID, "ID_GoogleGroup": ID_GoogleGroup, "IsFunction": IsFunction, "ID_Unit": ID_Unit, "GoogleGroup": GoogleGroup, "ID_SyncLevelType": ID_SyncLevelType, "SyncLevelType": SyncLevelType, "Units": Units, "SyncContactTypes": SyncContactTypes, "MembershipCategories": MembershipCategories, "FunctionsDirect": FunctionsDirect, "Functions": Functions, "ID_UnitType": ID_UnitType, "DisplayName": DisplayName})

    # Synchronizovat google účet
    def GoogleAccountUpdateSync(self, ID_Login, ID, UnitEmail=None, PersonEmail=None, OldGroup=None, NewGroup=None):
        return self._client.service.GoogleAccountUpdateSync({"ID_Login": ID_Login, "ID": ID, "UnitEmail": UnitEmail, "PersonEmail": PersonEmail, "OldGroup": OldGroup, "NewGroup": NewGroup})

    # Upravit typ synchronizace google skupiny
    def GoogleGroupUpdateSyncType(self, ID_Login, ID, ID_Unit, DateCreate, ID_GoogleGroupMain, ID_Domain, MemberCount, Valid, LastSync, IsAutoSync, DisplayName=None, Email=None, Unit=None, RegistrationNumber=None, GoogleGroupMainEmail=None, Description=None, EmailName=None, OwnerEmail=None, ID_SyncType=None, SyncType=None):
        return self._client.service.GoogleGroupUpdateSyncType({"ID_Login": ID_Login, "ID": ID, "ID_Unit": ID_Unit, "DateCreate": DateCreate, "ID_GoogleGroupMain": ID_GoogleGroupMain, "ID_Domain": ID_Domain, "MemberCount": MemberCount, "Valid": Valid, "LastSync": LastSync, "IsAutoSync": IsAutoSync, "DisplayName": DisplayName, "Email": Email, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "GoogleGroupMainEmail": GoogleGroupMainEmail, "Description": Description, "EmailName": EmailName, "OwnerEmail": OwnerEmail, "ID_SyncType": ID_SyncType, "SyncType": SyncType})

    # Synchronizovat google skupinu
    def GoogleGroupUpdateSync(self, ID_Login, ID, ID_Unit, DateCreate, ID_GoogleGroupMain, ID_Domain, MemberCount, Valid, LastSync, IsAutoSync, DisplayName=None, Email=None, Unit=None, RegistrationNumber=None, GoogleGroupMainEmail=None, Description=None, EmailName=None, OwnerEmail=None, ID_SyncType=None, SyncType=None):
        return self._client.service.GoogleGroupUpdateSync({"ID_Login": ID_Login, "ID": ID, "ID_Unit": ID_Unit, "DateCreate": DateCreate, "ID_GoogleGroupMain": ID_GoogleGroupMain, "ID_Domain": ID_Domain, "MemberCount": MemberCount, "Valid": Valid, "LastSync": LastSync, "IsAutoSync": IsAutoSync, "DisplayName": DisplayName, "Email": Email, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "GoogleGroupMainEmail": GoogleGroupMainEmail, "Description": Description, "EmailName": EmailName, "OwnerEmail": OwnerEmail, "ID_SyncType": ID_SyncType, "SyncType": SyncType})

    # Založit požadavek na synchronizaci
    def GoogleGroupSyncRequestInsert(self, ID_Login, ID, ID_GoogleGroup, Created, Synced, IsSyncing, GoogleGroup=None, Exception=None):
        return self._client.service.GoogleGroupSyncRequestInsert({"ID_Login": ID_Login, "ID": ID, "ID_GoogleGroup": ID_GoogleGroup, "Created": Created, "Synced": Synced, "IsSyncing": IsSyncing, "GoogleGroup": GoogleGroup, "Exception": Exception})

    # Dokončit požadavek na synchronizaci
    def GoogleGroupSyncRequestUpdateError(self, ID_Login, ID, ID_GoogleGroup, Created, Synced, IsSyncing, GoogleGroup=None, Exception=None):
        return self._client.service.GoogleGroupSyncRequestUpdateError({"ID_Login": ID_Login, "ID": ID, "ID_GoogleGroup": ID_GoogleGroup, "Created": Created, "Synced": Synced, "IsSyncing": IsSyncing, "GoogleGroup": GoogleGroup, "Exception": Exception})

    # Dokončit požadavek na synchronizaci
    def GoogleGroupSyncRequestUpdateFinish(self, ID_Login, ID, ID_GoogleGroup, Created, Synced, IsSyncing, GoogleGroup=None, Exception=None):
        return self._client.service.GoogleGroupSyncRequestUpdateFinish({"ID_Login": ID_Login, "ID": ID, "ID_GoogleGroup": ID_GoogleGroup, "Created": Created, "Synced": Synced, "IsSyncing": IsSyncing, "GoogleGroup": GoogleGroup, "Exception": Exception})

    # Načíst detail nastavení synchronizace Google skupiny
    def GoogleGroupSyncSettingsDetail(self, ID_Login, ID, ID_GoogleGroup):
        return self._client.service.GoogleGroupSyncSettingsDetail({"ID_Login": ID_Login, "ID": ID, "ID_GoogleGroup": ID_GoogleGroup})

    # Upravit nastavení synchronizace Google skupiny
    def GoogleGroupSyncSettingsUpdate(self, ID_Login, ID, ID_GoogleGroup, IsFunction, ID_Unit, GoogleGroup=None, ID_SyncLevelType=None, SyncLevelType=None, Units=None, SyncContactTypes=None, MembershipCategories=None, FunctionsDirect=None, Functions=None, ID_UnitType=None, DisplayName=None):
        return self._client.service.GoogleGroupSyncSettingsUpdate({"ID_Login": ID_Login, "ID": ID, "ID_GoogleGroup": ID_GoogleGroup, "IsFunction": IsFunction, "ID_Unit": ID_Unit, "GoogleGroup": GoogleGroup, "ID_SyncLevelType": ID_SyncLevelType, "SyncLevelType": SyncLevelType, "Units": Units, "SyncContactTypes": SyncContactTypes, "MembershipCategories": MembershipCategories, "FunctionsDirect": FunctionsDirect, "Functions": Functions, "ID_UnitType": ID_UnitType, "DisplayName": DisplayName})

    def SharedDriveDelete(self, ID_Login, ID):
        return self._client.service.SharedDriveDelete({"ID_Login": ID_Login, "ID": ID})

    # Načíst detail sdíleného disku
    def SharedDriveDetail(self, ID_Login, ID):
        return self._client.service.SharedDriveDetail({"ID_Login": ID_Login, "ID": ID})

    def SharedDriveInsert(self, ID_Login, ID, ID_Unit, DateCreated, ID_UserCreated, SpaceUsed, ID_PersonAdmin, DateUpdated, CheckConditions, ID_PersonCreated, ShowEventName, ShowAdminLink, DriveId=None, Unit=None, ID_SharedDriveType=None, SharedDriveType=None, DisplayName=None, EventName=None, UserCreated=None, AdminEmail=None, Note=None, OrgUnitPath=None, DateUpdatedClass=None):
        return self._client.service.SharedDriveInsert({"ID_Login": ID_Login, "ID": ID, "ID_Unit": ID_Unit, "DateCreated": DateCreated, "ID_UserCreated": ID_UserCreated, "SpaceUsed": SpaceUsed, "ID_PersonAdmin": ID_PersonAdmin, "DateUpdated": DateUpdated, "CheckConditions": CheckConditions, "ID_PersonCreated": ID_PersonCreated, "ShowEventName": ShowEventName, "ShowAdminLink": ShowAdminLink, "DriveId": DriveId, "Unit": Unit, "ID_SharedDriveType": ID_SharedDriveType, "SharedDriveType": SharedDriveType, "DisplayName": DisplayName, "EventName": EventName, "UserCreated": UserCreated, "AdminEmail": AdminEmail, "Note": Note, "OrgUnitPath": OrgUnitPath, "DateUpdatedClass": DateUpdatedClass})

    # Načíst seznam typů sdíleného disku
    def SharedDriveTypeAll(self, ID_Login, ID=None, DisplayName=None):
        return self._client.service.SharedDriveTypeAll({"ID_Login": ID_Login, "ID": ID, "DisplayName": DisplayName})

    # Upravit sdílený disk
    def SharedDriveUpdate(self, ID_Login, ID, ID_Unit, DateCreated, ID_UserCreated, SpaceUsed, ID_PersonAdmin, DateUpdated, CheckConditions, ID_PersonCreated, ShowEventName, ShowAdminLink, DriveId=None, Unit=None, ID_SharedDriveType=None, SharedDriveType=None, DisplayName=None, EventName=None, UserCreated=None, AdminEmail=None, Note=None, OrgUnitPath=None, DateUpdatedClass=None):
        return self._client.service.SharedDriveUpdate({"ID_Login": ID_Login, "ID": ID, "ID_Unit": ID_Unit, "DateCreated": DateCreated, "ID_UserCreated": ID_UserCreated, "SpaceUsed": SpaceUsed, "ID_PersonAdmin": ID_PersonAdmin, "DateUpdated": DateUpdated, "CheckConditions": CheckConditions, "ID_PersonCreated": ID_PersonCreated, "ShowEventName": ShowEventName, "ShowAdminLink": ShowAdminLink, "DriveId": DriveId, "Unit": Unit, "ID_SharedDriveType": ID_SharedDriveType, "SharedDriveType": SharedDriveType, "DisplayName": DisplayName, "EventName": EventName, "UserCreated": UserCreated, "AdminEmail": AdminEmail, "Note": Note, "OrgUnitPath": OrgUnitPath, "DateUpdatedClass": DateUpdatedClass})

    # Typ kontaktu pro synchronizaci
    def SyncContactTypeAll(self, ID_Login, ID=None, DisplayName=None):
        return self._client.service.SyncContactTypeAll({"ID_Login": ID_Login, "ID": ID, "DisplayName": DisplayName})

    def SyncLevelTypeAll(self, ID_Login, ID=None, DisplayName=None):
        return self._client.service.SyncLevelTypeAll({"ID_Login": ID_Login, "ID": ID, "DisplayName": DisplayName})

    # Načíst seznam typů funkce v nastavení Google skupiny
    def SyncSettingsFunctionTypeAll(self, ID_Login, ID_GoogleGroupSyncSettings, ID, ID_FunctionType):
        return self._client.service.SyncSettingsFunctionTypeAll({"ID_Login": ID_Login, "ID_GoogleGroupSyncSettings": ID_GoogleGroupSyncSettings, "ID": ID, "ID_FunctionType": ID_FunctionType})

    # Smazat typ funkce v nastavení Google skupiny
    def SyncSettingsFunctionTypeDelete(self, ID_Login, ID, ID_GoogleGroupSyncSettings, ID_FunctionType, IsDirect, FunctionType=None):
        return self._client.service.SyncSettingsFunctionTypeDelete({"ID_Login": ID_Login, "ID": ID, "ID_GoogleGroupSyncSettings": ID_GoogleGroupSyncSettings, "ID_FunctionType": ID_FunctionType, "IsDirect": IsDirect, "FunctionType": FunctionType})

    # Založit typ funkce v nastavení Google skupiny
    def SyncSettingsFunctionTypeInsert(self, ID_Login, ID, ID_GoogleGroupSyncSettings, ID_FunctionType, IsDirect, FunctionType=None):
        return self._client.service.SyncSettingsFunctionTypeInsert({"ID_Login": ID_Login, "ID": ID, "ID_GoogleGroupSyncSettings": ID_GoogleGroupSyncSettings, "ID_FunctionType": ID_FunctionType, "IsDirect": IsDirect, "FunctionType": FunctionType})

    # Načíst seznam kategorií členství v nastavení synchronizace Google skupiny
    def SyncSettingsMembershipCategoryAll(self, ID_Login, ID_GoogleGroupSyncSettings, ID, ID_MembershipCategory=None):
        return self._client.service.SyncSettingsMembershipCategoryAll({"ID_Login": ID_Login, "ID_GoogleGroupSyncSettings": ID_GoogleGroupSyncSettings, "ID": ID, "ID_MembershipCategory": ID_MembershipCategory})

    # Smazat kategorii členství v nastavení synchronizace Google skupiny
    def SyncSettingsMembershipCategoryDelete(self, ID_Login, ID, ID_GoogleGroupSyncSettings, MembershipCategories=None, ID_MembershipCategory=None, MembershipCategory=None, DisplayName=None):
        return self._client.service.SyncSettingsMembershipCategoryDelete({"ID_Login": ID_Login, "ID": ID, "ID_GoogleGroupSyncSettings": ID_GoogleGroupSyncSettings, "MembershipCategories": MembershipCategories, "ID_MembershipCategory": ID_MembershipCategory, "MembershipCategory": MembershipCategory, "DisplayName": DisplayName})

    # Založit kategorii členství v nastavení synchronizace Google skupiny
    def SyncSettingsMembershipCategoryInsert(self, ID_Login, ID, ID_GoogleGroupSyncSettings, MembershipCategories=None, ID_MembershipCategory=None, MembershipCategory=None, DisplayName=None):
        return self._client.service.SyncSettingsMembershipCategoryInsert({"ID_Login": ID_Login, "ID": ID, "ID_GoogleGroupSyncSettings": ID_GoogleGroupSyncSettings, "MembershipCategories": MembershipCategories, "ID_MembershipCategory": ID_MembershipCategory, "MembershipCategory": MembershipCategory, "DisplayName": DisplayName})

    # Načíst seznam typů kontaktu v nastavení synchronizace Google skupiny
    def SyncSettingsSyncContactTypeAll(self, ID_Login, ID_GoogleGroupSyncSettings, ID, ID_SyncContactType=None):
        return self._client.service.SyncSettingsSyncContactTypeAll({"ID_Login": ID_Login, "ID_GoogleGroupSyncSettings": ID_GoogleGroupSyncSettings, "ID": ID, "ID_SyncContactType": ID_SyncContactType})

    # Založit typ kontaktu nastavení synchronizace Google skupiny
    def SyncSettingsSyncContactTypeInsert(self, ID_Login, ID, ID_GoogleGroupSyncSettings, ID_SyncContactType=None, SyncContactType=None):
        return self._client.service.SyncSettingsSyncContactTypeInsert({"ID_Login": ID_Login, "ID": ID, "ID_GoogleGroupSyncSettings": ID_GoogleGroupSyncSettings, "ID_SyncContactType": ID_SyncContactType, "SyncContactType": SyncContactType})

    # Smazat typ kontaktu nastavení synchronizace Google skupiny
    def SyncSettingsSyncContactTypeDelete(self, ID_Login, ID, ID_GoogleGroupSyncSettings, ID_SyncContactType=None, SyncContactType=None):
        return self._client.service.SyncSettingsSyncContactTypeDelete({"ID_Login": ID_Login, "ID": ID, "ID_GoogleGroupSyncSettings": ID_GoogleGroupSyncSettings, "ID_SyncContactType": ID_SyncContactType, "SyncContactType": SyncContactType})

    # Načíst seznam jednotek v nastavení Google skupiny
    def SyncSettingsUnitAll(self, ID_Login, ID_GoogleGroupSyncSettings, ID, ID_Unit):
        return self._client.service.SyncSettingsUnitAll({"ID_Login": ID_Login, "ID_GoogleGroupSyncSettings": ID_GoogleGroupSyncSettings, "ID": ID, "ID_Unit": ID_Unit})

    # Smazat jednotku v nastavení Google skupiny
    def SyncSettingsUnitDelete(self, ID_Login, ID, ID_GoogleGroupSyncSettings, ID_Unit, Units=None, Unit=None, RegistrationNumber=None, DisplayName=None):
        return self._client.service.SyncSettingsUnitDelete({"ID_Login": ID_Login, "ID": ID, "ID_GoogleGroupSyncSettings": ID_GoogleGroupSyncSettings, "ID_Unit": ID_Unit, "Units": Units, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "DisplayName": DisplayName})

    # Založit jednotku v nastavení Google skupiny
    def SyncSettingsUnitInsert(self, ID_Login, ID, ID_GoogleGroupSyncSettings, ID_Unit, Units=None, Unit=None, RegistrationNumber=None, DisplayName=None):
        return self._client.service.SyncSettingsUnitInsert({"ID_Login": ID_Login, "ID": ID, "ID_GoogleGroupSyncSettings": ID_GoogleGroupSyncSettings, "ID_Unit": ID_Unit, "Units": Units, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "DisplayName": DisplayName})

    def SyncTypeAll(self, ID_Login, ID=None, DisplayName=None):
        return self._client.service.SyncTypeAll({"ID_Login": ID_Login, "ID": ID, "DisplayName": DisplayName})

    # Načíst seznam Google workspace předplatných jednotky
    def WorkspaceUnitAllUnit(self, ID_Login, ID_Unit, ID, ID_Person, SearchParent, DisplayName=None):
        return self._client.service.WorkspaceUnitAllUnit({"ID_Login": ID_Login, "ID_Unit": ID_Unit, "ID": ID, "ID_Person": ID_Person, "SearchParent": SearchParent, "DisplayName": DisplayName})

    # Načíst seznam GA účtů ke smazání
    def GoogleAccountAllInactive(self, ID_Login):
        return self._client.service.GoogleAccountAllInactive({"ID_Login": ID_Login})

    # Načíst seznam GA skupin ke smazání
    def GoogleGroupAllInactive(self, ID_Login):
        return self._client.service.GoogleGroupAllInactive({"ID_Login": ID_Login})

    # Načíst seznam správců domény
    def DomainAdminAll(self, ID_Login, ID_Domain, ID, ID_Person):
        return self._client.service.DomainAdminAll({"ID_Login": ID_Login, "ID_Domain": ID_Domain, "ID": ID, "ID_Person": ID_Person})

    # Načíst seznam správců domény
    def DomainAdminAllPerson(self, ID_Login, ID_Domain, ID, ID_Person):
        return self._client.service.DomainAdminAllPerson({"ID_Login": ID_Login, "ID_Domain": ID_Domain, "ID": ID, "ID_Person": ID_Person})

    # Smazat správce domény
    def DomainAdminDelete(self, ID_Login, ID):
        return self._client.service.DomainAdminDelete({"ID_Login": ID_Login, "ID": ID})

    # Založit správce domény
    def DomainAdminInsert(self, ID_Login, ID, ID_Domain, ID_Person, Domain=None, Person=None):
        return self._client.service.DomainAdminInsert({"ID_Login": ID_Login, "ID": ID, "ID_Domain": ID_Domain, "ID_Person": ID_Person, "Domain": Domain, "Person": Person})

    # Načíst seznam domén
    def DomainAll(self, ID_Login, ID, ID_Unit, DisplayName=None, ID_DomainState=None):
        return self._client.service.DomainAll({"ID_Login": ID_Login, "ID": ID, "ID_Unit": ID_Unit, "DisplayName": DisplayName, "ID_DomainState": ID_DomainState})

    # Načíst seznam domén dostupné pro osobu
    def DomainAllPerson(self, ID_Login, ID_Person, CanGoogleAccount):
        return self._client.service.DomainAllPerson({"ID_Login": ID_Login, "ID_Person": ID_Person, "CanGoogleAccount": CanGoogleAccount})

    # Načíst seznam domén jednotky
    def DomainAllUnit(self, ID_Login, ID, ID_Unit, DisplayName=None, ID_DomainState=None):
        return self._client.service.DomainAllUnit({"ID_Login": ID_Login, "ID": ID, "ID_Unit": ID_Unit, "DisplayName": DisplayName, "ID_DomainState": ID_DomainState})

    # Načíst seznam domén na kterých může uživatel založit účet pro danou jednotku
    def DomainAllUnitCreate(self, ID_Login, ID_Unit, CanGoogleAccount):
        return self._client.service.DomainAllUnitCreate({"ID_Login": ID_Login, "ID_Unit": ID_Unit, "CanGoogleAccount": CanGoogleAccount})

    # Načíst detail domény
    def DomainDetail(self, ID_Login, ID):
        return self._client.service.DomainDetail({"ID_Login": ID_Login, "ID": ID})

    # Načíst emaily založené pod doménou
    def DomainDetailEmails(self, ID_Login, ID):
        return self._client.service.DomainDetailEmails({"ID_Login": ID_Login, "ID": ID})

    # Založit doménu
    def DomainInsert(self, ID_Login, ID, ID_Unit, ID_PersonCreated, OnlyMember, OnlyAfter15, OnlyCinovnik, OnlyAdminCreate, DateActivate, IsUsed, ID_PersonAdmin, ActivateGA, ID_DomainMain, ValidateDomain, ValidateAdmin, Hosting, DisplayName=None, Description=None, Unit=None, RegistrationNumber=None, ID_DomainState=None, DomainState=None, PersonCreated=None, Note=None, Alias=None, DNS=None):
        return self._client.service.DomainInsert({"ID_Login": ID_Login, "ID": ID, "ID_Unit": ID_Unit, "ID_PersonCreated": ID_PersonCreated, "OnlyMember": OnlyMember, "OnlyAfter15": OnlyAfter15, "OnlyCinovnik": OnlyCinovnik, "OnlyAdminCreate": OnlyAdminCreate, "DateActivate": DateActivate, "IsUsed": IsUsed, "ID_PersonAdmin": ID_PersonAdmin, "ActivateGA": ActivateGA, "ID_DomainMain": ID_DomainMain, "ValidateDomain": ValidateDomain, "ValidateAdmin": ValidateAdmin, "Hosting": Hosting, "DisplayName": DisplayName, "Description": Description, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "ID_DomainState": ID_DomainState, "DomainState": DomainState, "PersonCreated": PersonCreated, "Note": Note, "Alias": Alias, "DNS": DNS})

    # Načíst seznam stavů domény
    def DomainStateAll(self, ID_Login, ID=None, DisplayName=None):
        return self._client.service.DomainStateAll({"ID_Login": ID_Login, "ID": ID, "DisplayName": DisplayName})

    # Načíst seznam jednotek přiřezené doméně
    def DomainUnitAll(self, ID_Login, ID_Domain, ID, ID_Unit):
        return self._client.service.DomainUnitAll({"ID_Login": ID_Login, "ID_Domain": ID_Domain, "ID": ID, "ID_Unit": ID_Unit})

    # Smazat jednotku přiřazenou doméně
    def DomainUnitDelete(self, ID_Login, ID):
        return self._client.service.DomainUnitDelete({"ID_Login": ID_Login, "ID": ID})

    # Založit jednotku přiřazenou doméně
    def DomainUnitInsert(self, ID_Login, ID, ID_Domain, ID_Unit, IncludeChildUnit, Domain=None, Unit=None, RegistrationNumber=None):
        return self._client.service.DomainUnitInsert({"ID_Login": ID_Login, "ID": ID, "ID_Domain": ID_Domain, "ID_Unit": ID_Unit, "IncludeChildUnit": IncludeChildUnit, "Domain": Domain, "Unit": Unit, "RegistrationNumber": RegistrationNumber})

    # Upravit doménu
    def DomainUpdate(self, ID_Login, ID, ID_Unit, ID_PersonCreated, OnlyMember, OnlyAfter15, OnlyCinovnik, OnlyAdminCreate, DateActivate, IsUsed, ID_PersonAdmin, ActivateGA, ID_DomainMain, ValidateDomain, ValidateAdmin, Hosting, DisplayName=None, Description=None, Unit=None, RegistrationNumber=None, ID_DomainState=None, DomainState=None, PersonCreated=None, Note=None, Alias=None, DNS=None):
        return self._client.service.DomainUpdate({"ID_Login": ID_Login, "ID": ID, "ID_Unit": ID_Unit, "ID_PersonCreated": ID_PersonCreated, "OnlyMember": OnlyMember, "OnlyAfter15": OnlyAfter15, "OnlyCinovnik": OnlyCinovnik, "OnlyAdminCreate": OnlyAdminCreate, "DateActivate": DateActivate, "IsUsed": IsUsed, "ID_PersonAdmin": ID_PersonAdmin, "ActivateGA": ActivateGA, "ID_DomainMain": ID_DomainMain, "ValidateDomain": ValidateDomain, "ValidateAdmin": ValidateAdmin, "Hosting": Hosting, "DisplayName": DisplayName, "Description": Description, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "ID_DomainState": ID_DomainState, "DomainState": DomainState, "PersonCreated": PersonCreated, "Note": Note, "Alias": Alias, "DNS": DNS})

    # Odeslat požadavek na doménu na ústředí
    def DomainUpdateActivate(self, ID_Login, ID, ID_Unit, ID_PersonCreated, OnlyMember, OnlyAfter15, OnlyCinovnik, OnlyAdminCreate, DateActivate, IsUsed, ID_PersonAdmin, ActivateGA, ID_DomainMain, ValidateDomain, ValidateAdmin, Hosting, DisplayName=None, Description=None, Unit=None, RegistrationNumber=None, ID_DomainState=None, DomainState=None, PersonCreated=None, Note=None, Alias=None, DNS=None):
        return self._client.service.DomainUpdateActivate({"ID_Login": ID_Login, "ID": ID, "ID_Unit": ID_Unit, "ID_PersonCreated": ID_PersonCreated, "OnlyMember": OnlyMember, "OnlyAfter15": OnlyAfter15, "OnlyCinovnik": OnlyCinovnik, "OnlyAdminCreate": OnlyAdminCreate, "DateActivate": DateActivate, "IsUsed": IsUsed, "ID_PersonAdmin": ID_PersonAdmin, "ActivateGA": ActivateGA, "ID_DomainMain": ID_DomainMain, "ValidateDomain": ValidateDomain, "ValidateAdmin": ValidateAdmin, "Hosting": Hosting, "DisplayName": DisplayName, "Description": Description, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "ID_DomainState": ID_DomainState, "DomainState": DomainState, "PersonCreated": PersonCreated, "Note": Note, "Alias": Alias, "DNS": DNS})

    # Upravit alias domény
    def DomainUpdateAlias(self, ID_Login, ID, ID_Unit, ID_PersonCreated, OnlyMember, OnlyAfter15, OnlyCinovnik, OnlyAdminCreate, DateActivate, IsUsed, ID_PersonAdmin, ActivateGA, ID_DomainMain, ValidateDomain, ValidateAdmin, Hosting, DisplayName=None, Description=None, Unit=None, RegistrationNumber=None, ID_DomainState=None, DomainState=None, PersonCreated=None, Note=None, Alias=None, DNS=None):
        return self._client.service.DomainUpdateAlias({"ID_Login": ID_Login, "ID": ID, "ID_Unit": ID_Unit, "ID_PersonCreated": ID_PersonCreated, "OnlyMember": OnlyMember, "OnlyAfter15": OnlyAfter15, "OnlyCinovnik": OnlyCinovnik, "OnlyAdminCreate": OnlyAdminCreate, "DateActivate": DateActivate, "IsUsed": IsUsed, "ID_PersonAdmin": ID_PersonAdmin, "ActivateGA": ActivateGA, "ID_DomainMain": ID_DomainMain, "ValidateDomain": ValidateDomain, "ValidateAdmin": ValidateAdmin, "Hosting": Hosting, "DisplayName": DisplayName, "Description": Description, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "ID_DomainState": ID_DomainState, "DomainState": DomainState, "PersonCreated": PersonCreated, "Note": Note, "Alias": Alias, "DNS": DNS})

    # Odeslat požadavek na doménu na ústředí
    def DomainUpdateApprove(self, ID_Login, ID, ID_Unit, ID_PersonCreated, OnlyMember, OnlyAfter15, OnlyCinovnik, OnlyAdminCreate, DateActivate, IsUsed, ID_PersonAdmin, ActivateGA, ID_DomainMain, ValidateDomain, ValidateAdmin, Hosting, DisplayName=None, Description=None, Unit=None, RegistrationNumber=None, ID_DomainState=None, DomainState=None, PersonCreated=None, Note=None, Alias=None, DNS=None):
        return self._client.service.DomainUpdateApprove({"ID_Login": ID_Login, "ID": ID, "ID_Unit": ID_Unit, "ID_PersonCreated": ID_PersonCreated, "OnlyMember": OnlyMember, "OnlyAfter15": OnlyAfter15, "OnlyCinovnik": OnlyCinovnik, "OnlyAdminCreate": OnlyAdminCreate, "DateActivate": DateActivate, "IsUsed": IsUsed, "ID_PersonAdmin": ID_PersonAdmin, "ActivateGA": ActivateGA, "ID_DomainMain": ID_DomainMain, "ValidateDomain": ValidateDomain, "ValidateAdmin": ValidateAdmin, "Hosting": Hosting, "DisplayName": DisplayName, "Description": Description, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "ID_DomainState": ID_DomainState, "DomainState": DomainState, "PersonCreated": PersonCreated, "Note": Note, "Alias": Alias, "DNS": DNS})

    # Upravit DNS záznam domény
    def DomainUpdateDNS(self, ID_Login, ID, ID_Unit, ID_PersonCreated, OnlyMember, OnlyAfter15, OnlyCinovnik, OnlyAdminCreate, DateActivate, IsUsed, ID_PersonAdmin, ActivateGA, ID_DomainMain, ValidateDomain, ValidateAdmin, Hosting, DisplayName=None, Description=None, Unit=None, RegistrationNumber=None, ID_DomainState=None, DomainState=None, PersonCreated=None, Note=None, Alias=None, DNS=None):
        return self._client.service.DomainUpdateDNS({"ID_Login": ID_Login, "ID": ID, "ID_Unit": ID_Unit, "ID_PersonCreated": ID_PersonCreated, "OnlyMember": OnlyMember, "OnlyAfter15": OnlyAfter15, "OnlyCinovnik": OnlyCinovnik, "OnlyAdminCreate": OnlyAdminCreate, "DateActivate": DateActivate, "IsUsed": IsUsed, "ID_PersonAdmin": ID_PersonAdmin, "ActivateGA": ActivateGA, "ID_DomainMain": ID_DomainMain, "ValidateDomain": ValidateDomain, "ValidateAdmin": ValidateAdmin, "Hosting": Hosting, "DisplayName": DisplayName, "Description": Description, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "ID_DomainState": ID_DomainState, "DomainState": DomainState, "PersonCreated": PersonCreated, "Note": Note, "Alias": Alias, "DNS": DNS})

    # Zapnout GA na doméně
    def DomainUpdateEnableGA(self, ID_Login, ID, ID_Unit, ID_PersonCreated, OnlyMember, OnlyAfter15, OnlyCinovnik, OnlyAdminCreate, DateActivate, IsUsed, ID_PersonAdmin, ActivateGA, ID_DomainMain, ValidateDomain, ValidateAdmin, Hosting, DisplayName=None, Description=None, Unit=None, RegistrationNumber=None, ID_DomainState=None, DomainState=None, PersonCreated=None, Note=None, Alias=None, DNS=None):
        return self._client.service.DomainUpdateEnableGA({"ID_Login": ID_Login, "ID": ID, "ID_Unit": ID_Unit, "ID_PersonCreated": ID_PersonCreated, "OnlyMember": OnlyMember, "OnlyAfter15": OnlyAfter15, "OnlyCinovnik": OnlyCinovnik, "OnlyAdminCreate": OnlyAdminCreate, "DateActivate": DateActivate, "IsUsed": IsUsed, "ID_PersonAdmin": ID_PersonAdmin, "ActivateGA": ActivateGA, "ID_DomainMain": ID_DomainMain, "ValidateDomain": ValidateDomain, "ValidateAdmin": ValidateAdmin, "Hosting": Hosting, "DisplayName": DisplayName, "Description": Description, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "ID_DomainState": ID_DomainState, "DomainState": DomainState, "PersonCreated": PersonCreated, "Note": Note, "Alias": Alias, "DNS": DNS})

    # Odeslat požadavek na doménu na ústředí
    def DomainUpdateSend(self, ID_Login, ID, ID_Unit, ID_PersonCreated, OnlyMember, OnlyAfter15, OnlyCinovnik, OnlyAdminCreate, DateActivate, IsUsed, ID_PersonAdmin, ActivateGA, ID_DomainMain, ValidateDomain, ValidateAdmin, Hosting, DisplayName=None, Description=None, Unit=None, RegistrationNumber=None, ID_DomainState=None, DomainState=None, PersonCreated=None, Note=None, Alias=None, DNS=None):
        return self._client.service.DomainUpdateSend({"ID_Login": ID_Login, "ID": ID, "ID_Unit": ID_Unit, "ID_PersonCreated": ID_PersonCreated, "OnlyMember": OnlyMember, "OnlyAfter15": OnlyAfter15, "OnlyCinovnik": OnlyCinovnik, "OnlyAdminCreate": OnlyAdminCreate, "DateActivate": DateActivate, "IsUsed": IsUsed, "ID_PersonAdmin": ID_PersonAdmin, "ActivateGA": ActivateGA, "ID_DomainMain": ID_DomainMain, "ValidateDomain": ValidateDomain, "ValidateAdmin": ValidateAdmin, "Hosting": Hosting, "DisplayName": DisplayName, "Description": Description, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "ID_DomainState": ID_DomainState, "DomainState": DomainState, "PersonCreated": PersonCreated, "Note": Note, "Alias": Alias, "DNS": DNS})

    # Upravit kdo na doméně může zakládat účty
    def DomainUpdateUsing(self, ID_Login, ID, ID_Unit, ID_PersonCreated, OnlyMember, OnlyAfter15, OnlyCinovnik, OnlyAdminCreate, DateActivate, IsUsed, ID_PersonAdmin, ActivateGA, ID_DomainMain, ValidateDomain, ValidateAdmin, Hosting, DisplayName=None, Description=None, Unit=None, RegistrationNumber=None, ID_DomainState=None, DomainState=None, PersonCreated=None, Note=None, Alias=None, DNS=None):
        return self._client.service.DomainUpdateUsing({"ID_Login": ID_Login, "ID": ID, "ID_Unit": ID_Unit, "ID_PersonCreated": ID_PersonCreated, "OnlyMember": OnlyMember, "OnlyAfter15": OnlyAfter15, "OnlyCinovnik": OnlyCinovnik, "OnlyAdminCreate": OnlyAdminCreate, "DateActivate": DateActivate, "IsUsed": IsUsed, "ID_PersonAdmin": ID_PersonAdmin, "ActivateGA": ActivateGA, "ID_DomainMain": ID_DomainMain, "ValidateDomain": ValidateDomain, "ValidateAdmin": ValidateAdmin, "Hosting": Hosting, "DisplayName": DisplayName, "Description": Description, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "ID_DomainState": ID_DomainState, "DomainState": DomainState, "PersonCreated": PersonCreated, "Note": Note, "Alias": Alias, "DNS": DNS})

    # Načíst seznam kontaktů osoby
    def GoogleAccountAll(self, ID_Login, ID_Person, ID, IsMain):
        return self._client.service.GoogleAccountAll({"ID_Login": ID_Login, "ID_Person": ID_Person, "ID": ID, "IsMain": IsMain})

    # Načíst seznam kontaktů osoby
    def GoogleAccountAllUnit(self, ID_Login, ID_Unit, ID, IsMain, ID_GoogleAccountMain, IncludeChildUnits):
        return self._client.service.GoogleAccountAllUnit({"ID_Login": ID_Login, "ID_Unit": ID_Unit, "ID": ID, "IsMain": IsMain, "ID_GoogleAccountMain": ID_GoogleAccountMain, "IncludeChildUnits": IncludeChildUnits})

    # Smazat účet v GA
    def GoogleAccountDelete(self, ID_Login, ID):
        return self._client.service.GoogleAccountDelete({"ID_Login": ID_Login, "ID": ID})

    # Smazat hlavni účet v GA
    def GoogleAccountDeleteMain(self, ID_Login, ID_Person, ID_GoogleAccount):
        return self._client.service.GoogleAccountDeleteMain({"ID_Login": ID_Login, "ID_Person": ID_Person, "ID_GoogleAccount": ID_GoogleAccount})

    # Načíst detail hlavního účtu jednotky v GA
    def GoogleAccountDetail(self, ID_Login, ID):
        return self._client.service.GoogleAccountDetail({"ID_Login": ID_Login, "ID": ID})

    # Načíst seznam kontaktů osoby
    def GoogleAccountDetailExists(self, ID_Login, IsMain, OnlyDb, Email=None):
        return self._client.service.GoogleAccountDetailExists({"ID_Login": ID_Login, "IsMain": IsMain, "OnlyDb": OnlyDb, "Email": Email})

    # Načíst detail hlavního účtu osoby v GA
    def GoogleAccountDetailMain(self, ID_Login, ID_Person, LoadMainEmail):
        return self._client.service.GoogleAccountDetailMain({"ID_Login": ID_Login, "ID_Person": ID_Person, "LoadMainEmail": LoadMainEmail})

    # Založit účet v GA osobě
    def GoogleAccountInsert(self, ID_Login, ID, ID_Person, ID_Unit, ID_Domain, IsMain, IsMainContact, Agrees, ID_UnitContact, ID_PersonContact, ID_PersonCreated, DateCreated, ID_GoogleAccount, OnlyValidate, ShareAllAdded, StorageCapacity, IsAdult, Person=None, Unit=None, UserName=None, Domain=None, Password=None, Password2=None, PersonCreated=None, Value=None, LoginUrl=None, DisplayNameFirst=None, DisplayNameLast=None, OrgUnitPath=None):
        return self._client.service.GoogleAccountInsert({"ID_Login": ID_Login, "ID": ID, "ID_Person": ID_Person, "ID_Unit": ID_Unit, "ID_Domain": ID_Domain, "IsMain": IsMain, "IsMainContact": IsMainContact, "Agrees": Agrees, "ID_UnitContact": ID_UnitContact, "ID_PersonContact": ID_PersonContact, "ID_PersonCreated": ID_PersonCreated, "DateCreated": DateCreated, "ID_GoogleAccount": ID_GoogleAccount, "OnlyValidate": OnlyValidate, "ShareAllAdded": ShareAllAdded, "StorageCapacity": StorageCapacity, "IsAdult": IsAdult, "Person": Person, "Unit": Unit, "UserName": UserName, "Domain": Domain, "Password": Password, "Password2": Password2, "PersonCreated": PersonCreated, "Value": Value, "LoginUrl": LoginUrl, "DisplayNameFirst": DisplayNameFirst, "DisplayNameLast": DisplayNameLast, "OrgUnitPath": OrgUnitPath})

    # Vynutit změnu hesla při dalším přihlášení do GA
    def GoogleAccountUpdateChangePassword(self, ID_Login, ID, ID_Person, ID_Unit, ID_Domain, IsMain, IsMainContact, Agrees, ID_UnitContact, ID_PersonContact, ID_PersonCreated, DateCreated, ID_GoogleAccount, OnlyValidate, ShareAllAdded, StorageCapacity, IsAdult, Person=None, Unit=None, UserName=None, Domain=None, Password=None, Password2=None, PersonCreated=None, Value=None, LoginUrl=None, DisplayNameFirst=None, DisplayNameLast=None, OrgUnitPath=None):
        return self._client.service.GoogleAccountUpdateChangePassword({"ID_Login": ID_Login, "ID": ID, "ID_Person": ID_Person, "ID_Unit": ID_Unit, "ID_Domain": ID_Domain, "IsMain": IsMain, "IsMainContact": IsMainContact, "Agrees": Agrees, "ID_UnitContact": ID_UnitContact, "ID_PersonContact": ID_PersonContact, "ID_PersonCreated": ID_PersonCreated, "DateCreated": DateCreated, "ID_GoogleAccount": ID_GoogleAccount, "OnlyValidate": OnlyValidate, "ShareAllAdded": ShareAllAdded, "StorageCapacity": StorageCapacity, "IsAdult": IsAdult, "Person": Person, "Unit": Unit, "UserName": UserName, "Domain": Domain, "Password": Password, "Password2": Password2, "PersonCreated": PersonCreated, "Value": Value, "LoginUrl": LoginUrl, "DisplayNameFirst": DisplayNameFirst, "DisplayNameLast": DisplayNameLast, "OrgUnitPath": OrgUnitPath})

    # Změna hesla
    def GoogleAccountUpdatePassword(self, ID_Login, ID, ID_Person, ID_Unit, ID_Domain, IsMain, IsMainContact, Agrees, ID_UnitContact, ID_PersonContact, ID_PersonCreated, DateCreated, ID_GoogleAccount, OnlyValidate, ShareAllAdded, StorageCapacity, IsAdult, Person=None, Unit=None, UserName=None, Domain=None, Password=None, Password2=None, PersonCreated=None, Value=None, LoginUrl=None, DisplayNameFirst=None, DisplayNameLast=None, OrgUnitPath=None):
        return self._client.service.GoogleAccountUpdatePassword({"ID_Login": ID_Login, "ID": ID, "ID_Person": ID_Person, "ID_Unit": ID_Unit, "ID_Domain": ID_Domain, "IsMain": IsMain, "IsMainContact": IsMainContact, "Agrees": Agrees, "ID_UnitContact": ID_UnitContact, "ID_PersonContact": ID_PersonContact, "ID_PersonCreated": ID_PersonCreated, "DateCreated": DateCreated, "ID_GoogleAccount": ID_GoogleAccount, "OnlyValidate": OnlyValidate, "ShareAllAdded": ShareAllAdded, "StorageCapacity": StorageCapacity, "IsAdult": IsAdult, "Person": Person, "Unit": Unit, "UserName": UserName, "Domain": Domain, "Password": Password, "Password2": Password2, "PersonCreated": PersonCreated, "Value": Value, "LoginUrl": LoginUrl, "DisplayNameFirst": DisplayNameFirst, "DisplayNameLast": DisplayNameLast, "OrgUnitPath": OrgUnitPath})

    # Načíst seznam google skupin
    def GoogleGroupAll(self, ID_Login, ID_Unit, ID, ID_GoogleGroupMain, IncludeChildUnits, DisplayName=None):
        return self._client.service.GoogleGroupAll({"ID_Login": ID_Login, "ID_Unit": ID_Unit, "ID": ID, "ID_GoogleGroupMain": ID_GoogleGroupMain, "IncludeChildUnits": IncludeChildUnits, "DisplayName": DisplayName})

    # Smazat google skupinu
    def GoogleGroupDelete(self, ID_Login, ID):
        return self._client.service.GoogleGroupDelete({"ID_Login": ID_Login, "ID": ID})

    # Smazat uzivatele z google skupiny
    def GoogleGroupDeleteMember(self, ID_Login, ID, Email=None):
        return self._client.service.GoogleGroupDeleteMember({"ID_Login": ID_Login, "ID": ID, "Email": Email})

    # Načíst detail google skupiny
    def GoogleGroupDetail(self, ID_Login, ID):
        return self._client.service.GoogleGroupDetail({"ID_Login": ID_Login, "ID": ID})

    # Založit google skupinu
    def GoogleGroupInsert(self, ID_Login, ID, ID_Unit, DateCreate, ID_GoogleGroupMain, ID_Domain, MemberCount, Valid, LastSync, IsAutoSync, DisplayName=None, Email=None, Unit=None, RegistrationNumber=None, GoogleGroupMainEmail=None, Description=None, EmailName=None, OwnerEmail=None, ID_SyncType=None, SyncType=None):
        return self._client.service.GoogleGroupInsert({"ID_Login": ID_Login, "ID": ID, "ID_Unit": ID_Unit, "DateCreate": DateCreate, "ID_GoogleGroupMain": ID_GoogleGroupMain, "ID_Domain": ID_Domain, "MemberCount": MemberCount, "Valid": Valid, "LastSync": LastSync, "IsAutoSync": IsAutoSync, "DisplayName": DisplayName, "Email": Email, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "GoogleGroupMainEmail": GoogleGroupMainEmail, "Description": Description, "EmailName": EmailName, "OwnerEmail": OwnerEmail, "ID_SyncType": ID_SyncType, "SyncType": SyncType})

    # Upravit google skupinu
    def GoogleGroupUpdate(self, ID_Login, ID, ID_Unit, DateCreate, ID_GoogleGroupMain, ID_Domain, MemberCount, Valid, LastSync, IsAutoSync, DisplayName=None, Email=None, Unit=None, RegistrationNumber=None, GoogleGroupMainEmail=None, Description=None, EmailName=None, OwnerEmail=None, ID_SyncType=None, SyncType=None):
        return self._client.service.GoogleGroupUpdate({"ID_Login": ID_Login, "ID": ID, "ID_Unit": ID_Unit, "DateCreate": DateCreate, "ID_GoogleGroupMain": ID_GoogleGroupMain, "ID_Domain": ID_Domain, "MemberCount": MemberCount, "Valid": Valid, "LastSync": LastSync, "IsAutoSync": IsAutoSync, "DisplayName": DisplayName, "Email": Email, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "GoogleGroupMainEmail": GoogleGroupMainEmail, "Description": Description, "EmailName": EmailName, "OwnerEmail": OwnerEmail, "ID_SyncType": ID_SyncType, "SyncType": SyncType})

    # Uložit členy skupiny dle emailu
    def GoogleGroupUpdateMemberEmail(self, ID_Login, ID, EmailArray=None):
        return self._client.service.GoogleGroupUpdateMemberEmail({"ID_Login": ID_Login, "ID": ID, "EmailArray": EmailArray})

    # Uložit osobu jako člena skupiny
    def GoogleGroupUpdateMemberPerson(self, ID_Login, ID, ID_Person):
        return self._client.service.GoogleGroupUpdateMemberPerson({"ID_Login": ID_Login, "ID": ID, "ID_Person": ID_Person})

    # Upravit roli uzivatele
    def GoogleGroupUpdateMemberRole(self, ID_Login, ID, IsOwner, Email=None):
        return self._client.service.GoogleGroupUpdateMemberRole({"ID_Login": ID_Login, "ID": ID, "IsOwner": IsOwner, "Email": Email})




import zeep

# Webová služba pro práci s materiálem a sklady
class Material:
    __module__ = 'skautis'

    def __init__(self, test):
        if test:
            self._client = zeep.Client('https://test-is.skaut.cz/JunakWebservice/Material.asmx?wsdl')
        else:
            self._client = zeep.Client('https://is.skaut.cz/JunakWebservice/Material.asmx?wsdl')

    # Převod položek do skladu
    def WarehouseItemUpdateTransfer(self, ID_Login, ID_Warehouse, WarehouseItems=None):
        return self._client.service.WarehouseItemUpdateTransfer({"ID_Login": ID_Login, "ID_Warehouse": ID_Warehouse, "WarehouseItems": WarehouseItems})

    # Načíst seznam typu pořízení
    def PurchaseTypeAll(self, ID_Login, ID=None, DisplayName=None):
        return self._client.service.PurchaseTypeAll({"ID_Login": ID_Login, "ID": ID, "DisplayName": DisplayName})

    # Načíst seznam inventur
    def StockTakingAll(self, ID_Login, ID_Unit, ID, ID_Person, ID_DocumentStockTaking, ID_DocumentProtocol, OpenOnly, ID_StockTakingState=None):
        return self._client.service.StockTakingAll({"ID_Login": ID_Login, "ID_Unit": ID_Unit, "ID": ID, "ID_Person": ID_Person, "ID_DocumentStockTaking": ID_DocumentStockTaking, "ID_DocumentProtocol": ID_DocumentProtocol, "OpenOnly": OpenOnly, "ID_StockTakingState": ID_StockTakingState})

    # Smazat inventuru
    def StockTakingDelete(self, ID_Login, ID):
        return self._client.service.StockTakingDelete({"ID_Login": ID_Login, "ID": ID})

    # Načíst detail inventury
    def StockTakingDetail(self, ID_Login, ID):
        return self._client.service.StockTakingDetail({"ID_Login": ID_Login, "ID": ID})

    # Založit inventuru
    def StockTakingInsert(self, WarehouseList=None):
        return self._client.service.StockTakingInsert({"WarehouseList": WarehouseList})

    # Načíst seznam stavů inventury
    def StockTakingStateAll(self, ID_Login, ID=None, DisplayName=None):
        return self._client.service.StockTakingStateAll({"ID_Login": ID_Login, "ID": ID, "DisplayName": DisplayName})

    # Načíst seznam typů inventarizace
    def StockTakingTypeAll(self, ID_Login, ID=None, DisplayName=None):
        return self._client.service.StockTakingTypeAll({"ID_Login": ID_Login, "ID": ID, "DisplayName": DisplayName})

    # Upravit stav inventury
    def StockTakingUpdateState(self, ID_Login, ID, ID_Person, Date, Created, ID_DocumentStockTaking, ID_DocumentProtocol, ID_DocumentStockTakingTempFile, ID_DocumentProtocolTempFile, ID_Unit, ID_StockTakingState=None, StockTakingState=None, ID_StockTakingType=None, StockTakingType=None, Person=None, Note=None, DocumentStockTaking=None, DocumentProtocol=None, Unit=None, UnitFullName=None, RegistrationNumber=None, Warehouses=None):
        return self._client.service.StockTakingUpdateState({"ID_Login": ID_Login, "ID": ID, "ID_Person": ID_Person, "Date": Date, "Created": Created, "ID_DocumentStockTaking": ID_DocumentStockTaking, "ID_DocumentProtocol": ID_DocumentProtocol, "ID_DocumentStockTakingTempFile": ID_DocumentStockTakingTempFile, "ID_DocumentProtocolTempFile": ID_DocumentProtocolTempFile, "ID_Unit": ID_Unit, "ID_StockTakingState": ID_StockTakingState, "StockTakingState": StockTakingState, "ID_StockTakingType": ID_StockTakingType, "StockTakingType": StockTakingType, "Person": Person, "Note": Note, "DocumentStockTaking": DocumentStockTaking, "DocumentProtocol": DocumentProtocol, "Unit": Unit, "UnitFullName": UnitFullName, "RegistrationNumber": RegistrationNumber, "Warehouses": Warehouses})

    # Upravit inventuru
    def StockTakingUpdate(self, ID_Login, ID, ID_Person, Date, Created, ID_DocumentStockTaking, ID_DocumentProtocol, ID_DocumentStockTakingTempFile, ID_DocumentProtocolTempFile, ID_Unit, ID_StockTakingState=None, StockTakingState=None, ID_StockTakingType=None, StockTakingType=None, Person=None, Note=None, DocumentStockTaking=None, DocumentProtocol=None, Unit=None, UnitFullName=None, RegistrationNumber=None, Warehouses=None):
        return self._client.service.StockTakingUpdate({"ID_Login": ID_Login, "ID": ID, "ID_Person": ID_Person, "Date": Date, "Created": Created, "ID_DocumentStockTaking": ID_DocumentStockTaking, "ID_DocumentProtocol": ID_DocumentProtocol, "ID_DocumentStockTakingTempFile": ID_DocumentStockTakingTempFile, "ID_DocumentProtocolTempFile": ID_DocumentProtocolTempFile, "ID_Unit": ID_Unit, "ID_StockTakingState": ID_StockTakingState, "StockTakingState": StockTakingState, "ID_StockTakingType": ID_StockTakingType, "StockTakingType": StockTakingType, "Person": Person, "Note": Note, "DocumentStockTaking": DocumentStockTaking, "DocumentProtocol": DocumentProtocol, "Unit": Unit, "UnitFullName": UnitFullName, "RegistrationNumber": RegistrationNumber, "Warehouses": Warehouses})

    # Načíst seznam inventarizovaných položek skladu
    def StockTakingWarehouseItemAll(self, ID_Login, ID_StockTaking, ID, ID_WarehouseItem):
        return self._client.service.StockTakingWarehouseItemAll({"ID_Login": ID_Login, "ID_StockTaking": ID_StockTaking, "ID": ID, "ID_WarehouseItem": ID_WarehouseItem})

    # Smazat inventarizovanou položku skladu
    def StockTakingWarehouseItemDelete(self, ID_Login, ID):
        return self._client.service.StockTakingWarehouseItemDelete({"ID_Login": ID_Login, "ID": ID})

    # Založit inventarizovanou položku skladu
    def StockTakingWarehouseItemInsert(self, ID_Login, ID_StockTaking, ID_WarehouseItem, WarehouseItems=None, Note=None):
        return self._client.service.StockTakingWarehouseItemInsert({"ID_Login": ID_Login, "ID_StockTaking": ID_StockTaking, "ID_WarehouseItem": ID_WarehouseItem, "WarehouseItems": WarehouseItems, "Note": Note})

    # Načíst seznam správců skladu
    def WarehouseAdminAll(self, ID_Login, ID_Event, ID_EventEducation, ID_EventGeneral, ID, ID_Person):
        return self._client.service.WarehouseAdminAll({"ID_Login": ID_Login, "ID_Event": ID_Event, "ID_EventEducation": ID_EventEducation, "ID_EventGeneral": ID_EventGeneral, "ID": ID, "ID_Person": ID_Person})

    # Smazat správce skladu
    def WarehouseAdminDelete(self, ID_Login, ID):
        return self._client.service.WarehouseAdminDelete({"ID_Login": ID_Login, "ID": ID})

    # Založit správce skladu
    def WarehouseAdminInsert(self, ID_Login, ID, ID_Event, ID_EventEducation, ID_EventGeneral, ID_Person, Event=None, Person=None, Note=None):
        return self._client.service.WarehouseAdminInsert({"ID_Login": ID_Login, "ID": ID, "ID_Event": ID_Event, "ID_EventEducation": ID_EventEducation, "ID_EventGeneral": ID_EventGeneral, "ID_Person": ID_Person, "Event": Event, "Person": Person, "Note": Note})

    # Načíst seznam skladů
    def WarehouseAllProperty(self, ID_Login, ID_Unit, IsChildIncluded):
        return self._client.service.WarehouseAllProperty({"ID_Login": ID_Login, "ID_Unit": ID_Unit, "IsChildIncluded": IsChildIncluded})

    # Načíst seznam skladů inventury jednotky
    def WarehouseAllStockTakingUnit(self, ID_Login, ID_Unit, IsChildIncluded):
        return self._client.service.WarehouseAllStockTakingUnit({"ID_Login": ID_Login, "ID_Unit": ID_Unit, "IsChildIncluded": IsChildIncluded})

    # Načíst seznam skladů k inventuře jednotky
    def WarehouseAllStockTaking(self, ID_Login, ID_StockTaking, ID_Warehouse):
        return self._client.service.WarehouseAllStockTaking({"ID_Login": ID_Login, "ID_StockTaking": ID_StockTaking, "ID_Warehouse": ID_Warehouse})

    # Načíst seznam skladů
    def WarehouseAllEvent(self, ID_Login, ID_EventEducation, ID_EventGeneral, ID, ID_WarehouseMain, ID_District, IsChildIncluded, DisplayName=None, ID_WarehouseType=None):
        return self._client.service.WarehouseAllEvent({"ID_Login": ID_Login, "ID_EventEducation": ID_EventEducation, "ID_EventGeneral": ID_EventGeneral, "ID": ID, "ID_WarehouseMain": ID_WarehouseMain, "ID_District": ID_District, "IsChildIncluded": IsChildIncluded, "DisplayName": DisplayName, "ID_WarehouseType": ID_WarehouseType})

    # Načíst seznam skladů, ze kterých si můžu půjčovat
    def WarehouseAllBorrowable(self, ID_Login):
        return self._client.service.WarehouseAllBorrowable({"ID_Login": ID_Login})

    # Smazat sklad
    def WarehouseDelete(self, ID_Login, ID):
        return self._client.service.WarehouseDelete({"ID_Login": ID_Login, "ID": ID})

    # Načíst seznam štítků položek
    def WarehouseItemAllBarcode(self, ID_Login, ID_Items=None):
        return self._client.service.WarehouseItemAllBarcode({"ID_Login": ID_Login, "ID_Items": ID_Items})

    # Načíst seznam položek k likvidaci inventurizace jednotky
    def WarehouseItemAllStockTakingDiscarded(self, ID_Login, ID_StockTaking, ID_Warehouse):
        return self._client.service.WarehouseItemAllStockTakingDiscarded({"ID_Login": ID_Login, "ID_StockTaking": ID_StockTaking, "ID_Warehouse": ID_Warehouse})

    # Načíst seznam položek inventurizace jednotky
    def WarehouseItemAllStockTaking(self, ID_Login, ID_StockTaking, ID_Warehouse):
        return self._client.service.WarehouseItemAllStockTaking({"ID_Login": ID_Login, "ID_StockTaking": ID_StockTaking, "ID_Warehouse": ID_Warehouse})

    # Načíst seznam položek jednotky
    def WarehouseItemAllEvent(self, ID_Login, ID_EventEducation, ID_EventGeneral, ID, IncludeChild, EventRent, UnitRent, CommercialRent, IsDelete, InWarehouse, Count, RowMin, Reverse, DisplayName=None, InventoryNumber=None, ID_WarehouseArray=None, ID_WarehouseTagArray=None, Sort=None, ID_WarehouseItemCategory=None):
        return self._client.service.WarehouseItemAllEvent({"ID_Login": ID_Login, "ID_EventEducation": ID_EventEducation, "ID_EventGeneral": ID_EventGeneral, "ID": ID, "IncludeChild": IncludeChild, "EventRent": EventRent, "UnitRent": UnitRent, "CommercialRent": CommercialRent, "IsDelete": IsDelete, "InWarehouse": InWarehouse, "Count": Count, "RowMin": RowMin, "Reverse": Reverse, "DisplayName": DisplayName, "InventoryNumber": InventoryNumber, "ID_WarehouseArray": ID_WarehouseArray, "ID_WarehouseTagArray": ID_WarehouseTagArray, "Sort": Sort, "ID_WarehouseItemCategory": ID_WarehouseItemCategory})

    # Načíst seznam všech položek skladu, které si lze zapůjčit
    def WarehouseItemAllBorrowable(self, ID_Login, ID_Application, MaxPrice, IsInStock, IsCommercial, DateFrom, DateTo, Keyword=None, Category=None, District=None, Region=None, City=None):
        return self._client.service.WarehouseItemAllBorrowable({"ID_Login": ID_Login, "ID_Application": ID_Application, "MaxPrice": MaxPrice, "IsInStock": IsInStock, "IsCommercial": IsCommercial, "DateFrom": DateFrom, "DateTo": DateTo, "Keyword": Keyword, "Category": Category, "District": District, "Region": Region, "City": City})

    # Načíst vypůjčené položky a rezervace
    def WarehouseItemAllLent(self, ID_Login, ID_Unit, ID, IncludeChild, EventRent, UnitRent, CommercialRent, IsDelete, InWarehouse, Count, RowMin, Reverse, ShowActive, ShowOnlyUnfinished, DisplayName=None, InventoryNumber=None, ID_WarehouseArray=None, ID_WarehouseTagArray=None, Sort=None, ID_WarehouseItemCategory=None):
        return self._client.service.WarehouseItemAllLent({"ID_Login": ID_Login, "ID_Unit": ID_Unit, "ID": ID, "IncludeChild": IncludeChild, "EventRent": EventRent, "UnitRent": UnitRent, "CommercialRent": CommercialRent, "IsDelete": IsDelete, "InWarehouse": InWarehouse, "Count": Count, "RowMin": RowMin, "Reverse": Reverse, "ShowActive": ShowActive, "ShowOnlyUnfinished": ShowOnlyUnfinished, "DisplayName": DisplayName, "InventoryNumber": InventoryNumber, "ID_WarehouseArray": ID_WarehouseArray, "ID_WarehouseTagArray": ID_WarehouseTagArray, "Sort": Sort, "ID_WarehouseItemCategory": ID_WarehouseItemCategory})

    # Načíst seznam položek jednotky
    def WarehouseItemAll(self, ID_Login, ID_Unit, ID, IncludeChild, EventRent, UnitRent, CommercialRent, IsDelete, InWarehouse, Count, RowMin, Reverse, ID_Items=None, DisplayName=None, InventoryNumber=None, ID_WarehouseArray=None, ID_WarehouseTagArray=None, Sort=None, ID_WarehouseItemCategory=None):
        return self._client.service.WarehouseItemAll({"ID_Login": ID_Login, "ID_Unit": ID_Unit, "ID": ID, "IncludeChild": IncludeChild, "EventRent": EventRent, "UnitRent": UnitRent, "CommercialRent": CommercialRent, "IsDelete": IsDelete, "InWarehouse": InWarehouse, "Count": Count, "RowMin": RowMin, "Reverse": Reverse, "ID_Items": ID_Items, "DisplayName": DisplayName, "InventoryNumber": InventoryNumber, "ID_WarehouseArray": ID_WarehouseArray, "ID_WarehouseTagArray": ID_WarehouseTagArray, "Sort": Sort, "ID_WarehouseItemCategory": ID_WarehouseItemCategory})

    # Načíst názvy položek
    def WarehouseItemAllDisplayName(self, ID_Login, ID=None):
        return self._client.service.WarehouseItemAllDisplayName({"ID_Login": ID_Login, "ID": ID})

    # Načíst seznam kategorií
    def WarehouseItemCategoryAllWithIntend(self, ID_Login, ID=None):
        return self._client.service.WarehouseItemCategoryAllWithIntend({"ID_Login": ID_Login, "ID": ID})

    # Načíst seznam kategorií
    def WarehouseItemCategoryAll(self, ID_Login, ID=None, DisplayName=None, ID_WarehouseItemCategoryParent=None):
        return self._client.service.WarehouseItemCategoryAll({"ID_Login": ID_Login, "ID": ID, "DisplayName": DisplayName, "ID_WarehouseItemCategoryParent": ID_WarehouseItemCategoryParent})

    def WarehouseItemDelete(self, ID_Login, ID):
        return self._client.service.WarehouseItemDelete({"ID_Login": ID_Login, "ID": ID})

    # Načíst detail položky
    def WarehouseItemDetail(self, ID_Login, ID):
        return self._client.service.WarehouseItemDetail({"ID_Login": ID_Login, "ID": ID})

    # Načíst detail položky
    def WarehouseItemDetailPhoto(self, ID_Login, ID_Application, ID, Size=None):
        return self._client.service.WarehouseItemDetailPhoto({"ID_Login": ID_Login, "ID_Application": ID_Application, "ID": ID, "Size": Size})

    # Založit položku
    def WarehouseItemInsert(self, ID_Login, ID, ID_Unit, ID_Event, ID_Warehouse, ID_TempFile, ID_Document, PurchaseDate, PurchaseYear, PurchasePrice, ActualPrice, DeletionDate, EventRent, UnitRent, CommercialRent, RentPrice, InWarehouse, InventoryDate, EventName=None, DisplayName=None, Warehouse=None, ID_WarehouseItemCategory=None, WarehouseItemCategory=None, InventoryNumber=None, Description=None, FileExtension=None, ID_PurchaseType=None, PurchaseType=None, PurchaseNote=None, SerialNumber=None, Sails=None, AccountNumber=None, DeletionNote=None, RentNote=None, Note=None, Tags=None, WarehouseRentNote=None, WarehouseTag=None, InventoryNote=None):
        return self._client.service.WarehouseItemInsert({"ID_Login": ID_Login, "ID": ID, "ID_Unit": ID_Unit, "ID_Event": ID_Event, "ID_Warehouse": ID_Warehouse, "ID_TempFile": ID_TempFile, "ID_Document": ID_Document, "PurchaseDate": PurchaseDate, "PurchaseYear": PurchaseYear, "PurchasePrice": PurchasePrice, "ActualPrice": ActualPrice, "DeletionDate": DeletionDate, "EventRent": EventRent, "UnitRent": UnitRent, "CommercialRent": CommercialRent, "RentPrice": RentPrice, "InWarehouse": InWarehouse, "InventoryDate": InventoryDate, "EventName": EventName, "DisplayName": DisplayName, "Warehouse": Warehouse, "ID_WarehouseItemCategory": ID_WarehouseItemCategory, "WarehouseItemCategory": WarehouseItemCategory, "InventoryNumber": InventoryNumber, "Description": Description, "FileExtension": FileExtension, "ID_PurchaseType": ID_PurchaseType, "PurchaseType": PurchaseType, "PurchaseNote": PurchaseNote, "SerialNumber": SerialNumber, "Sails": Sails, "AccountNumber": AccountNumber, "DeletionNote": DeletionNote, "RentNote": RentNote, "Note": Note, "Tags": Tags, "WarehouseRentNote": WarehouseRentNote, "WarehouseTag": WarehouseTag, "InventoryNote": InventoryNote})

    # Načíst seznam inventur
    def WarehouseItemInventoryAll(self, ID_Login, ID_WarehouseItem, ID, ID_Person):
        return self._client.service.WarehouseItemInventoryAll({"ID_Login": ID_Login, "ID_WarehouseItem": ID_WarehouseItem, "ID": ID, "ID_Person": ID_Person})

    # Založit inventuru
    def WarehouseItemInventoryInsert(self, ID_Login, ID, ID_WarehouseItem, ID_Person, Date, WarehouseItem=None, Person=None, Note=None):
        return self._client.service.WarehouseItemInventoryInsert({"ID_Login": ID_Login, "ID": ID, "ID_WarehouseItem": ID_WarehouseItem, "ID_Person": ID_Person, "Date": Date, "WarehouseItem": WarehouseItem, "Person": Person, "Note": Note})

    # Smazat výpůjčku
    def WarehouseItemRentDelete(self, ID_Login, ID_WarehouseItem=None):
        return self._client.service.WarehouseItemRentDelete({"ID_Login": ID_Login, "ID_WarehouseItem": ID_WarehouseItem})

    # Založit výpůjčku
    def WarehouseItemRentInsert(self, ID_Login, ID_WarehouseItemReservation, StartDate, EndDate, ID_WarehouseItem=None, Note=None):
        return self._client.service.WarehouseItemRentInsert({"ID_Login": ID_Login, "ID_WarehouseItemReservation": ID_WarehouseItemReservation, "StartDate": StartDate, "EndDate": EndDate, "ID_WarehouseItem": ID_WarehouseItem, "Note": Note})

    # Načíst seznam typů půjčení
    def WarehouseItemRentTypeAll(self, ID_Login, ID=None, DisplayName=None):
        return self._client.service.WarehouseItemRentTypeAll({"ID_Login": ID_Login, "ID": ID, "DisplayName": DisplayName})

    # Upravit výpůjčku
    def WarehouseItemRentUpdate(self, ID_Login, ID, ID_WarehouseItem, StartDate, EndDate, IsActive, WarehouseItem=None, Note=None):
        return self._client.service.WarehouseItemRentUpdate({"ID_Login": ID_Login, "ID": ID, "ID_WarehouseItem": ID_WarehouseItem, "StartDate": StartDate, "EndDate": EndDate, "IsActive": IsActive, "WarehouseItem": WarehouseItem, "Note": Note})

    # Načíst seznam tagů položek
    def WarehouseItemTagAll(self, ID_Login, ID_WarehouseItem, ID, ID_WarehouseTag):
        return self._client.service.WarehouseItemTagAll({"ID_Login": ID_Login, "ID_WarehouseItem": ID_WarehouseItem, "ID": ID, "ID_WarehouseTag": ID_WarehouseTag})

    # Upravit položku
    def WarehouseItemUpdateBatch(self, ID_Login, ID, ID_Unit, ID_Event, ID_Warehouse, ID_TempFile, ID_Document, PurchaseDate, PurchaseYear, PurchasePrice, ActualPrice, DeletionDate, EventRent, UnitRent, CommercialRent, RentPrice, InWarehouse, InventoryDate, EventName=None, DisplayName=None, Warehouse=None, ID_WarehouseItemCategory=None, WarehouseItemCategory=None, InventoryNumber=None, Description=None, FileExtension=None, ID_PurchaseType=None, PurchaseType=None, PurchaseNote=None, SerialNumber=None, Sails=None, AccountNumber=None, DeletionNote=None, RentNote=None, Note=None, Tags=None, WarehouseRentNote=None, WarehouseTag=None, InventoryNote=None):
        return self._client.service.WarehouseItemUpdateBatch({"ID_Login": ID_Login, "ID": ID, "ID_Unit": ID_Unit, "ID_Event": ID_Event, "ID_Warehouse": ID_Warehouse, "ID_TempFile": ID_TempFile, "ID_Document": ID_Document, "PurchaseDate": PurchaseDate, "PurchaseYear": PurchaseYear, "PurchasePrice": PurchasePrice, "ActualPrice": ActualPrice, "DeletionDate": DeletionDate, "EventRent": EventRent, "UnitRent": UnitRent, "CommercialRent": CommercialRent, "RentPrice": RentPrice, "InWarehouse": InWarehouse, "InventoryDate": InventoryDate, "EventName": EventName, "DisplayName": DisplayName, "Warehouse": Warehouse, "ID_WarehouseItemCategory": ID_WarehouseItemCategory, "WarehouseItemCategory": WarehouseItemCategory, "InventoryNumber": InventoryNumber, "Description": Description, "FileExtension": FileExtension, "ID_PurchaseType": ID_PurchaseType, "PurchaseType": PurchaseType, "PurchaseNote": PurchaseNote, "SerialNumber": SerialNumber, "Sails": Sails, "AccountNumber": AccountNumber, "DeletionNote": DeletionNote, "RentNote": RentNote, "Note": Note, "Tags": Tags, "WarehouseRentNote": WarehouseRentNote, "WarehouseTag": WarehouseTag, "InventoryNote": InventoryNote})

    # Vyřadit položku
    def WarehouseItemUpdateDelete(self, ID_Login, DeletionDate, ID=None, DeletionNote=None):
        return self._client.service.WarehouseItemUpdateDelete({"ID_Login": ID_Login, "DeletionDate": DeletionDate, "ID": ID, "DeletionNote": DeletionNote})

    # Upravit fotografii u položky
    def WarehouseItemUpdatePhoto(self, ID_Login, ID, ID_Unit, ID_Event, ID_Warehouse, ID_TempFile, ID_Document, PurchaseDate, PurchaseYear, PurchasePrice, ActualPrice, DeletionDate, EventRent, UnitRent, CommercialRent, RentPrice, InWarehouse, InventoryDate, EventName=None, DisplayName=None, Warehouse=None, ID_WarehouseItemCategory=None, WarehouseItemCategory=None, InventoryNumber=None, Description=None, FileExtension=None, ID_PurchaseType=None, PurchaseType=None, PurchaseNote=None, SerialNumber=None, Sails=None, AccountNumber=None, DeletionNote=None, RentNote=None, Note=None, Tags=None, WarehouseRentNote=None, WarehouseTag=None, InventoryNote=None):
        return self._client.service.WarehouseItemUpdatePhoto({"ID_Login": ID_Login, "ID": ID, "ID_Unit": ID_Unit, "ID_Event": ID_Event, "ID_Warehouse": ID_Warehouse, "ID_TempFile": ID_TempFile, "ID_Document": ID_Document, "PurchaseDate": PurchaseDate, "PurchaseYear": PurchaseYear, "PurchasePrice": PurchasePrice, "ActualPrice": ActualPrice, "DeletionDate": DeletionDate, "EventRent": EventRent, "UnitRent": UnitRent, "CommercialRent": CommercialRent, "RentPrice": RentPrice, "InWarehouse": InWarehouse, "InventoryDate": InventoryDate, "EventName": EventName, "DisplayName": DisplayName, "Warehouse": Warehouse, "ID_WarehouseItemCategory": ID_WarehouseItemCategory, "WarehouseItemCategory": WarehouseItemCategory, "InventoryNumber": InventoryNumber, "Description": Description, "FileExtension": FileExtension, "ID_PurchaseType": ID_PurchaseType, "PurchaseType": PurchaseType, "PurchaseNote": PurchaseNote, "SerialNumber": SerialNumber, "Sails": Sails, "AccountNumber": AccountNumber, "DeletionNote": DeletionNote, "RentNote": RentNote, "Note": Note, "Tags": Tags, "WarehouseRentNote": WarehouseRentNote, "WarehouseTag": WarehouseTag, "InventoryNote": InventoryNote})

    # Upravit položku
    def WarehouseItemUpdate(self, DeletePhoto):
        return self._client.service.WarehouseItemUpdate({"DeletePhoto": DeletePhoto})

    # Upravit více položek
    def WarehouseItemUpdateMulti(self, ID_Login, ID=None, DisplayName=None, Description=None, ID_WarehouseItemCategory=None, ID_Warehouse=None, InventoryNumber=None, SerialNumber=None, PurchaseDate=None, PurchasePrice=None, ID_PurchaseType=None, PurchaseNote=None, ActualPrice=None, AccountNumber=None, DeletionDate=None, DeletionNote=None, EventRent=None, UnitRent=None, CommercialRent=None, RentPrice=None, RentNote=None, Note=None, ID_TempFilePhoto=None):
        return self._client.service.WarehouseItemUpdateMulti({"ID_Login": ID_Login, "ID": ID, "DisplayName": DisplayName, "Description": Description, "ID_WarehouseItemCategory": ID_WarehouseItemCategory, "ID_Warehouse": ID_Warehouse, "InventoryNumber": InventoryNumber, "SerialNumber": SerialNumber, "PurchaseDate": PurchaseDate, "PurchasePrice": PurchasePrice, "ID_PurchaseType": ID_PurchaseType, "PurchaseNote": PurchaseNote, "ActualPrice": ActualPrice, "AccountNumber": AccountNumber, "DeletionDate": DeletionDate, "DeletionNote": DeletionNote, "EventRent": EventRent, "UnitRent": UnitRent, "CommercialRent": CommercialRent, "RentPrice": RentPrice, "RentNote": RentNote, "Note": Note, "ID_TempFilePhoto": ID_TempFilePhoto})

    # Načíst seznam inventarizovaných skladu
    def WarehouseStockTakingAll(self, ID_Login, ID_Warehouse, ID, ID_StockTaking):
        return self._client.service.WarehouseStockTakingAll({"ID_Login": ID_Login, "ID_Warehouse": ID_Warehouse, "ID": ID, "ID_StockTaking": ID_StockTaking})

    # Smazat inventarizovaný skladu
    def WarehouseStockTakingDelete(self, ID_Login, ID):
        return self._client.service.WarehouseStockTakingDelete({"ID_Login": ID_Login, "ID": ID})

    # Založit inventarizovaný skladu
    def WarehouseStockTakingInsert(self, ID_Login, ID, ID_Warehouse, ID_StockTaking, Warehouse=None, Note=None):
        return self._client.service.WarehouseStockTakingInsert({"ID_Login": ID_Login, "ID": ID, "ID_Warehouse": ID_Warehouse, "ID_StockTaking": ID_StockTaking, "Warehouse": Warehouse, "Note": Note})

    # Načíst seznam tagů
    def WarehouseTagAllUniversal(self, ID_Login, ID_EventEducation, ID_EventGeneral, ID_Unit, ID, DisplayName=None):
        return self._client.service.WarehouseTagAllUniversal({"ID_Login": ID_Login, "ID_EventEducation": ID_EventEducation, "ID_EventGeneral": ID_EventGeneral, "ID_Unit": ID_Unit, "ID": ID, "DisplayName": DisplayName})

    # Založit tag
    def WarehouseTagInsertEvent(self, ID_Login, ID, ID_Unit, ID_EventEducation, ID_EventGeneral, ID_Event, ID_Warehouse, CanUpdate, DisplayName=None, Unit=None, Event=None, RegistrationNumber=None, Color=None, Warehouse=None):
        return self._client.service.WarehouseTagInsertEvent({"ID_Login": ID_Login, "ID": ID, "ID_Unit": ID_Unit, "ID_EventEducation": ID_EventEducation, "ID_EventGeneral": ID_EventGeneral, "ID_Event": ID_Event, "ID_Warehouse": ID_Warehouse, "CanUpdate": CanUpdate, "DisplayName": DisplayName, "Unit": Unit, "Event": Event, "RegistrationNumber": RegistrationNumber, "Color": Color, "Warehouse": Warehouse})

    # Upravit platnost skladu
    def WarehouseUpdateEnabled(self, ID_Login, ID, ID_Unit, ID_Event, ID_WarehouseMain, IsDefault, ID_District, GpsLatitude, GpsLongitude, CanUpdate, ID_UnitCentral, IsEnabled, DisplayName=None, ID_WarehouseType=None, WarehouseType=None, Unit=None, UnitFullName=None, RegistrationNumber=None, Event=None, WarehouseMain=None, Street=None, City=None, District=None, Postcode=None, Note=None, UnitCentral=None, UnitCentralFullName=None, UnitCentralRegistrationNumber=None):
        return self._client.service.WarehouseUpdateEnabled({"ID_Login": ID_Login, "ID": ID, "ID_Unit": ID_Unit, "ID_Event": ID_Event, "ID_WarehouseMain": ID_WarehouseMain, "IsDefault": IsDefault, "ID_District": ID_District, "GpsLatitude": GpsLatitude, "GpsLongitude": GpsLongitude, "CanUpdate": CanUpdate, "ID_UnitCentral": ID_UnitCentral, "IsEnabled": IsEnabled, "DisplayName": DisplayName, "ID_WarehouseType": ID_WarehouseType, "WarehouseType": WarehouseType, "Unit": Unit, "UnitFullName": UnitFullName, "RegistrationNumber": RegistrationNumber, "Event": Event, "WarehouseMain": WarehouseMain, "Street": Street, "City": City, "District": District, "Postcode": Postcode, "Note": Note, "UnitCentral": UnitCentral, "UnitCentralFullName": UnitCentralFullName, "UnitCentralRegistrationNumber": UnitCentralRegistrationNumber})

    # Načíst seznam skladů
    def WarehouseAll(self, ID_Login, ID_Unit, ID, ID_Event, ID_WarehouseMain, ID_District, IsChildIncluded, IsEnabled, DisplayName=None, ID_WarehouseType=None):
        return self._client.service.WarehouseAll({"ID_Login": ID_Login, "ID_Unit": ID_Unit, "ID": ID, "ID_Event": ID_Event, "ID_WarehouseMain": ID_WarehouseMain, "ID_District": ID_District, "IsChildIncluded": IsChildIncluded, "IsEnabled": IsEnabled, "DisplayName": DisplayName, "ID_WarehouseType": ID_WarehouseType})

    # Načíst detail skladu
    def WarehouseDetail(self, ID_Login, ID):
        return self._client.service.WarehouseDetail({"ID_Login": ID_Login, "ID": ID})

    # Založit sklad
    def WarehouseInsert(self, ID_Login, ID, ID_Unit, ID_Event, ID_WarehouseMain, IsDefault, ID_District, GpsLatitude, GpsLongitude, CanUpdate, ID_UnitCentral, IsEnabled, DisplayName=None, ID_WarehouseType=None, WarehouseType=None, Unit=None, UnitFullName=None, RegistrationNumber=None, Event=None, WarehouseMain=None, Street=None, City=None, District=None, Postcode=None, Note=None, UnitCentral=None, UnitCentralFullName=None, UnitCentralRegistrationNumber=None):
        return self._client.service.WarehouseInsert({"ID_Login": ID_Login, "ID": ID, "ID_Unit": ID_Unit, "ID_Event": ID_Event, "ID_WarehouseMain": ID_WarehouseMain, "IsDefault": IsDefault, "ID_District": ID_District, "GpsLatitude": GpsLatitude, "GpsLongitude": GpsLongitude, "CanUpdate": CanUpdate, "ID_UnitCentral": ID_UnitCentral, "IsEnabled": IsEnabled, "DisplayName": DisplayName, "ID_WarehouseType": ID_WarehouseType, "WarehouseType": WarehouseType, "Unit": Unit, "UnitFullName": UnitFullName, "RegistrationNumber": RegistrationNumber, "Event": Event, "WarehouseMain": WarehouseMain, "Street": Street, "City": City, "District": District, "Postcode": Postcode, "Note": Note, "UnitCentral": UnitCentral, "UnitCentralFullName": UnitCentralFullName, "UnitCentralRegistrationNumber": UnitCentralRegistrationNumber})

    # Načíst seznam tagů
    def WarehouseTagAll(self, ID_Login, ID_Unit, ID, ID_Warehouse, IncludeChild, UniqueOnly, DisplayName=None):
        return self._client.service.WarehouseTagAll({"ID_Login": ID_Login, "ID_Unit": ID_Unit, "ID": ID, "ID_Warehouse": ID_Warehouse, "IncludeChild": IncludeChild, "UniqueOnly": UniqueOnly, "DisplayName": DisplayName})

    # Smazat tag
    def WarehouseTagDelete(self, ID_Login, ID, ID_Warehouse):
        return self._client.service.WarehouseTagDelete({"ID_Login": ID_Login, "ID": ID, "ID_Warehouse": ID_Warehouse})

    # Načíst detail tagu
    def WarehouseTagDetail(self, ID_Login, ID):
        return self._client.service.WarehouseTagDetail({"ID_Login": ID_Login, "ID": ID})

    # Založit tag
    def WarehouseTagInsert(self, ID_Login, ID_Unit, DisplayName=None, Color=None, ID_Warehouse=None):
        return self._client.service.WarehouseTagInsert({"ID_Login": ID_Login, "ID_Unit": ID_Unit, "DisplayName": DisplayName, "Color": Color, "ID_Warehouse": ID_Warehouse})

    # Upravit tag
    def WarehouseTagUpdate(self, ID_Login, ID, ID_Unit, ID_EventEducation, ID_EventGeneral, ID_Event, ID_Warehouse, CanUpdate, DisplayName=None, Unit=None, Event=None, RegistrationNumber=None, Color=None, Warehouse=None):
        return self._client.service.WarehouseTagUpdate({"ID_Login": ID_Login, "ID": ID, "ID_Unit": ID_Unit, "ID_EventEducation": ID_EventEducation, "ID_EventGeneral": ID_EventGeneral, "ID_Event": ID_Event, "ID_Warehouse": ID_Warehouse, "CanUpdate": CanUpdate, "DisplayName": DisplayName, "Unit": Unit, "Event": Event, "RegistrationNumber": RegistrationNumber, "Color": Color, "Warehouse": Warehouse})

    # Načíst seznam typů skladů
    def WarehouseTypeAll(self, ID_Login, ID=None, DisplayName=None):
        return self._client.service.WarehouseTypeAll({"ID_Login": ID_Login, "ID": ID, "DisplayName": DisplayName})

    # Nastavit sklad jako výchozí
    def WarehouseUpdateIsDefault(self, ID_Login, ID, ID_Unit, ID_Event, ID_WarehouseMain, IsDefault, ID_District, GpsLatitude, GpsLongitude, CanUpdate, ID_UnitCentral, IsEnabled, DisplayName=None, ID_WarehouseType=None, WarehouseType=None, Unit=None, UnitFullName=None, RegistrationNumber=None, Event=None, WarehouseMain=None, Street=None, City=None, District=None, Postcode=None, Note=None, UnitCentral=None, UnitCentralFullName=None, UnitCentralRegistrationNumber=None):
        return self._client.service.WarehouseUpdateIsDefault({"ID_Login": ID_Login, "ID": ID, "ID_Unit": ID_Unit, "ID_Event": ID_Event, "ID_WarehouseMain": ID_WarehouseMain, "IsDefault": IsDefault, "ID_District": ID_District, "GpsLatitude": GpsLatitude, "GpsLongitude": GpsLongitude, "CanUpdate": CanUpdate, "ID_UnitCentral": ID_UnitCentral, "IsEnabled": IsEnabled, "DisplayName": DisplayName, "ID_WarehouseType": ID_WarehouseType, "WarehouseType": WarehouseType, "Unit": Unit, "UnitFullName": UnitFullName, "RegistrationNumber": RegistrationNumber, "Event": Event, "WarehouseMain": WarehouseMain, "Street": Street, "City": City, "District": District, "Postcode": Postcode, "Note": Note, "UnitCentral": UnitCentral, "UnitCentralFullName": UnitCentralFullName, "UnitCentralRegistrationNumber": UnitCentralRegistrationNumber})

    # Upravit sklad
    def WarehouseUpdate(self, ID_Login, ID, ID_Unit, ID_Event, ID_WarehouseMain, IsDefault, ID_District, GpsLatitude, GpsLongitude, CanUpdate, ID_UnitCentral, IsEnabled, DisplayName=None, ID_WarehouseType=None, WarehouseType=None, Unit=None, UnitFullName=None, RegistrationNumber=None, Event=None, WarehouseMain=None, Street=None, City=None, District=None, Postcode=None, Note=None, UnitCentral=None, UnitCentralFullName=None, UnitCentralRegistrationNumber=None):
        return self._client.service.WarehouseUpdate({"ID_Login": ID_Login, "ID": ID, "ID_Unit": ID_Unit, "ID_Event": ID_Event, "ID_WarehouseMain": ID_WarehouseMain, "IsDefault": IsDefault, "ID_District": ID_District, "GpsLatitude": GpsLatitude, "GpsLongitude": GpsLongitude, "CanUpdate": CanUpdate, "ID_UnitCentral": ID_UnitCentral, "IsEnabled": IsEnabled, "DisplayName": DisplayName, "ID_WarehouseType": ID_WarehouseType, "WarehouseType": WarehouseType, "Unit": Unit, "UnitFullName": UnitFullName, "RegistrationNumber": RegistrationNumber, "Event": Event, "WarehouseMain": WarehouseMain, "Street": Street, "City": City, "District": District, "Postcode": Postcode, "Note": Note, "UnitCentral": UnitCentral, "UnitCentralFullName": UnitCentralFullName, "UnitCentralRegistrationNumber": UnitCentralRegistrationNumber})




import zeep

# Správa externích aplikací přistupujících ke skautISu
class ApplicationManagement:
    __module__ = 'skautis'

    def __init__(self, test):
        if test:
            self._client = zeep.Client('https://test-is.skaut.cz/JunakWebservice/ApplicationManagement.asmx?wsdl')
        else:
            self._client = zeep.Client('https://is.skaut.cz/JunakWebservice/ApplicationManagement.asmx?wsdl')

    # Načíst seznam oprávnění aplikace
    def ApplicationOperationAll(self, ID_Login, ID_Application, ID_Operation=None, ID_Action=None):
        return self._client.service.ApplicationOperationAll({"ID_Login": ID_Login, "ID_Application": ID_Application, "ID_Operation": ID_Operation, "ID_Action": ID_Action})

    # Smazat oprávnění aplikace
    def ApplicationOperationDelete(self, ID_Login, ID):
        return self._client.service.ApplicationOperationDelete({"ID_Login": ID_Login, "ID": ID})

    # Založit oprávnění aplikace
    def ApplicationOperationInsert(self, ID_Login, ID_Application, ID_Operation=None, ID_Action=None):
        return self._client.service.ApplicationOperationInsert({"ID_Login": ID_Login, "ID_Application": ID_Application, "ID_Operation": ID_Operation, "ID_Action": ID_Action})

    # Načíst seznam akcí balíčku práv
    def PackageActionAll(self, ID_Login, ID_Package, ID, ID_Action=None):
        return self._client.service.PackageActionAll({"ID_Login": ID_Login, "ID_Package": ID_Package, "ID": ID, "ID_Action": ID_Action})

    # Smazat akci balíčku práv
    def PackageActionDelete(self, ID_Login, ID, ID_Package, Package=None, ID_Action=None, Action=None):
        return self._client.service.PackageActionDelete({"ID_Login": ID_Login, "ID": ID, "ID_Package": ID_Package, "Package": Package, "ID_Action": ID_Action, "Action": Action})

    # Založit akci balíčku práv
    def PackageActionInsert(self, ID_Login, ID, ID_Package, Package=None, ID_Action=None, Action=None):
        return self._client.service.PackageActionInsert({"ID_Login": ID_Login, "ID": ID, "ID_Package": ID_Package, "Package": Package, "ID_Action": ID_Action, "Action": Action})

    # Načíst seznam balíčků práv
    def PackageAll(self, ID_Login, ID, ID_Application, DisplayName=None):
        return self._client.service.PackageAll({"ID_Login": ID_Login, "ID": ID, "ID_Application": ID_Application, "DisplayName": DisplayName})

    # Načíst seznam balíčků v externí aplikace
    def PackageApplicationAll(self, ID_Login, ID, ID_Package, ID_Application):
        return self._client.service.PackageApplicationAll({"ID_Login": ID_Login, "ID": ID, "ID_Package": ID_Package, "ID_Application": ID_Application})

    # Smazat balíček v externí aplikace
    def PackageApplicationDelete(self, ID_Login, ID, ID_Package, ID_Application, Package=None, Application=None):
        return self._client.service.PackageApplicationDelete({"ID_Login": ID_Login, "ID": ID, "ID_Package": ID_Package, "ID_Application": ID_Application, "Package": Package, "Application": Application})

    # Založit balíček v externí aplikace
    def PackageApplicationInsert(self, ID_Login, ID, ID_Package, ID_Application, Package=None, Application=None):
        return self._client.service.PackageApplicationInsert({"ID_Login": ID_Login, "ID": ID, "ID_Package": ID_Package, "ID_Application": ID_Application, "Package": Package, "Application": Application})

    # Smazat balíček práv
    def PackageDelete(self, ID_Login, ID):
        return self._client.service.PackageDelete({"ID_Login": ID_Login, "ID": ID})

    # Načíst detail balíčku práv
    def PackageDetail(self, ID_Login, ID):
        return self._client.service.PackageDetail({"ID_Login": ID_Login, "ID": ID})

    # Založit balíček práv
    def PackageInsert(self, ID_Login, ID, IsActive, DisplayName=None, Note=None):
        return self._client.service.PackageInsert({"ID_Login": ID_Login, "ID": ID, "IsActive": IsActive, "DisplayName": DisplayName, "Note": Note})

    # Načíst seznam operací balíčku práv
    def PackageOperationAll(self, ID_Login, ID_Package, ID, ID_Operation=None):
        return self._client.service.PackageOperationAll({"ID_Login": ID_Login, "ID_Package": ID_Package, "ID": ID, "ID_Operation": ID_Operation})

    # Smazat operaci balíčku práv
    def PackageOperationDelete(self, ID_Login, ID, ID_Package, Package=None, ID_Operation=None, Operation=None):
        return self._client.service.PackageOperationDelete({"ID_Login": ID_Login, "ID": ID, "ID_Package": ID_Package, "Package": Package, "ID_Operation": ID_Operation, "Operation": Operation})

    # Založit operaci balíčku práv
    def PackageOperationInsert(self, ID_Login, ID, ID_Package, Package=None, ID_Operation=None, Operation=None):
        return self._client.service.PackageOperationInsert({"ID_Login": ID_Login, "ID": ID, "ID_Package": ID_Package, "Package": Package, "ID_Operation": ID_Operation, "Operation": Operation})

    # Aktualizovat aplikace
    def PackageUpdateSyncPermission(self, ID_Login, ID, IsActive, DisplayName=None, Note=None):
        return self._client.service.PackageUpdateSyncPermission({"ID_Login": ID_Login, "ID": ID, "IsActive": IsActive, "DisplayName": DisplayName, "Note": Note})

    # Upravit balíček práv
    def PackageUpdate(self, ID_Login, ID, IsActive, DisplayName=None, Note=None):
        return self._client.service.PackageUpdate({"ID_Login": ID_Login, "ID": ID, "IsActive": IsActive, "DisplayName": DisplayName, "Note": Note})

    # Načtení informací o externí aplikaci
    def RemoteApplicationDelete(self, ID_Login, ID_Application):
        return self._client.service.RemoteApplicationDelete({"ID_Login": ID_Login, "ID_Application": ID_Application})

    # Načíst seznam externích aplikací
    def RemoteApplicationAll(self):
        return self._client.service.RemoteApplicationAll(None)

    # Načtení informací o externí aplikaci
    def RemoteApplicationDetail(self, idApplication):
        return self._client.service.RemoteApplicationDetail(idApplication=idApplication)

    # Založení nové externí aplikace
    def RemoteApplicationInsert(self, ID_Login, ID_Application, Enabled, ID_Unit, ID_Person, IsAnonymous, IsAllActions, IsPersistentLogin, ID_Role, ID_GroupLogin, DisplayName=None, Description=None, Unit=None, RegistrationNumber=None, UnitName=None, Person=None, IP=None, Url=None, UrlLoginPage=None, UrlLogoutPage=None, UrlInfoPanel=None, ValidReturnUrl=None, Role=None):
        return self._client.service.RemoteApplicationInsert({"ID_Login": ID_Login, "ID_Application": ID_Application, "Enabled": Enabled, "ID_Unit": ID_Unit, "ID_Person": ID_Person, "IsAnonymous": IsAnonymous, "IsAllActions": IsAllActions, "IsPersistentLogin": IsPersistentLogin, "ID_Role": ID_Role, "ID_GroupLogin": ID_GroupLogin, "DisplayName": DisplayName, "Description": Description, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "UnitName": UnitName, "Person": Person, "IP": IP, "Url": Url, "UrlLoginPage": UrlLoginPage, "UrlLogoutPage": UrlLogoutPage, "UrlInfoPanel": UrlInfoPanel, "ValidReturnUrl": ValidReturnUrl, "Role": Role})

    # Editace externí aplikace
    def RemoteApplicationUpdate(self, ID_Login, ID_Application, Enabled, ID_Unit, ID_Person, IsAnonymous, IsAllActions, IsPersistentLogin, ID_Role, ID_GroupLogin, DisplayName=None, Description=None, Unit=None, RegistrationNumber=None, UnitName=None, Person=None, IP=None, Url=None, UrlLoginPage=None, UrlLogoutPage=None, UrlInfoPanel=None, ValidReturnUrl=None, Role=None):
        return self._client.service.RemoteApplicationUpdate({"ID_Login": ID_Login, "ID_Application": ID_Application, "Enabled": Enabled, "ID_Unit": ID_Unit, "ID_Person": ID_Person, "IsAnonymous": IsAnonymous, "IsAllActions": IsAllActions, "IsPersistentLogin": IsPersistentLogin, "ID_Role": ID_Role, "ID_GroupLogin": ID_GroupLogin, "DisplayName": DisplayName, "Description": Description, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "UnitName": UnitName, "Person": Person, "IP": IP, "Url": Url, "UrlLoginPage": UrlLoginPage, "UrlLogoutPage": UrlLogoutPage, "UrlInfoPanel": UrlInfoPanel, "ValidReturnUrl": ValidReturnUrl, "Role": Role})

